@@ -218,7 +218,7 @@ static void status_init_pipe(void)
 	if ((tmpdir = getenv("TMPDIR")) == NULL)
 		tmpdir = "/tmp";
 
-	asprintf(&pipename, "%s/%s", tmpdir, PIPENAME);
+	xasprintf(&pipename, "%s/%s", tmpdir, PIPENAME);
 
 	unlink(pipename);
 	if ((mkfifo(pipename, 0666) == -1)) {
@@ -250,24 +250,6 @@ static void status_init_pipe(void)
 	free(pipename);
 }
 
-/** Prepend rather than replace the image path.
-    Used for obsolete PixmapPath and IconPath **/
-static void obsolete_imagepaths( const char* pre_path )
-{
-	char* tmp = stripcpy( pre_path );
-	char* path = alloca(strlen( tmp ) + strlen(PictureGetImagePath()) + 2 );
-
-	strcpy( path, tmp );
-	free( tmp );
-
-	strcat( path, ":" );
-	strcat( path, PictureGetImagePath() );
-
-	PictureSetImagePath( path );
-
-	return;
-}
-
 /*
  *
  * Reads a title button description (veliaa@rpi.edu)
@@ -544,7 +526,7 @@ static void __remove_window_decors(F_CMD_ARGS, FvwmDecor *d)
 			exc2 = exc_clone_context(
 				exc, &ecc, ECC_FW | ECC_WCONTEXT);
 			execute_function(
-				cond_rc, exc2, "ChangeDecor Default", 0);
+				cond_rc, exc2, "ChangeDecor Default", pc, 0);
 			exc_destroy_context(exc2);
 		}
 	}
@@ -1418,7 +1400,7 @@ void ApplyDefaultFontAndColors(void)
 {
 	XGCValues gcv;
 	unsigned long gcm;
-	int cset = Scr.DefaultColorset;
+	int cset = 0;
 
 	/* make GC's */
 	gcm = GCFunction|GCLineWidth|GCForeground|GCBackground;
@@ -1429,16 +1411,9 @@ void ApplyDefaultFontAndColors(void)
 		gcv.font = Scr.DefaultFont->font->fid;
 	}
 	gcv.line_width = 0;
-	if (cset >= 0)
-	{
-		gcv.foreground = Colorset[cset].fg;
-		gcv.background = Colorset[cset].bg;
-	}
-	else
-	{
-		gcv.foreground = Scr.StdFore;
-		gcv.background = Scr.StdBack;
-	}
+	gcv.foreground = Colorset[cset].fg;
+	gcv.background = Colorset[cset].bg;
+
 	if (Scr.StdGC)
 	{
 		XChangeGC(dpy, Scr.StdGC, gcm, &gcv);
@@ -1449,14 +1424,8 @@ void ApplyDefaultFontAndColors(void)
 	}
 
 	gcm = GCFunction|GCLineWidth|GCForeground;
-	if (cset >= 0)
-	{
-		gcv.foreground = Colorset[cset].hilite;
-	}
-	else
-	{
-		gcv.foreground = Scr.StdHilite;
-	}
+	gcv.foreground = Colorset[cset].hilite;
+
 	if (Scr.StdReliefGC)
 	{
 		XChangeGC(dpy, Scr.StdReliefGC, gcm, &gcv);
@@ -1466,14 +1435,8 @@ void ApplyDefaultFontAndColors(void)
 		Scr.StdReliefGC = fvwmlib_XCreateGC(
 			dpy, Scr.NoFocusWin, gcm, &gcv);
 	}
-	if (cset >= 0)
-	{
-		gcv.foreground = Colorset[cset].shadow;
-	}
-	else
-	{
-		gcv.foreground = Scr.StdShadow;
-	}
+
+	gcv.foreground = Colorset[cset].shadow;
 	if (Scr.StdShadowGC)
 	{
 		XChangeGC(dpy, Scr.StdShadowGC, gcm, &gcv);
@@ -1493,17 +1456,15 @@ void ApplyDefaultFontAndColors(void)
 	return;
 }
 
-void FreeDecorFace(Display *dpy, DecorFace *df)
+void FreeDecorFace(Display *disp, DecorFace *df)
 {
-	int i;
-
 	switch (DFS_FACE_TYPE(df->style))
 	{
 	case GradientButton:
 		if (df->u.grad.d_pixels != NULL && df->u.grad.d_npixels)
 		{
 			PictureFreeColors(
-				dpy, Pcmap, df->u.grad.d_pixels,
+				disp, Pcmap, df->u.grad.d_pixels,
 				df->u.grad.d_npixels, 0, False);
 			free(df->u.grad.d_pixels);
 		}
@@ -1519,7 +1480,7 @@ void FreeDecorFace(Display *dpy, DecorFace *df)
 				p[i] = df->u.grad.xcs[i].pixel;
 			}
 			PictureFreeColors(
-				dpy, Pcmap, p, df->u.grad.npixels, 0, False);
+				disp, Pcmap, p, df->u.grad.npixels, 0, False);
 			free(p);
 		}
 		if (df->u.grad.xcs != NULL)
@@ -1535,24 +1496,26 @@ void FreeDecorFace(Display *dpy, DecorFace *df)
 	case ShrunkPixmapButton:
 		if (df->u.p)
 		{
-			PDestroyFvwmPicture(dpy, df->u.p);
+			PDestroyFvwmPicture(disp, df->u.p);
 		}
 		break;
 
 	case MultiPixmap:
 		if (df->u.mp.pixmaps)
 		{
+			int i;
+
 			for (i = 0; i < TBMP_NUM_PIXMAPS; i++)
 			{
 				if (df->u.mp.pixmaps[i])
 				{
 					PDestroyFvwmPicture(
-						dpy, df->u.mp.pixmaps[i]);
+						disp, df->u.mp.pixmaps[i]);
 				}
 				else if (!!(df->u.mp.solid_flags & i))
 				{
 					PictureFreeColors(
-						dpy, Pcmap, &df->u.mp.pixels[i],
+						disp, Pcmap, &df->u.mp.pixels[i],
 						1, 0, False);
 				}
 			}
@@ -1598,7 +1561,7 @@ void FreeDecorFace(Display *dpy, DecorFace *df)
 	/* delete any compound styles */
 	if (df->next)
 	{
-		FreeDecorFace(dpy, df->next);
+		FreeDecorFace(disp, df->next);
 		free(df->next);
 	}
 	df->next = NULL;
@@ -2166,7 +2129,7 @@ void AddToDecor(F_CMD_ARGS, FvwmDecor *decor)
 		return;
 	}
 	Scr.cur_decor = decor;
-	execute_function(cond_rc, exc, action, 0);
+	execute_function(F_PASS_ARGS, 0);
 	Scr.cur_decor = NULL;
 
 	return;
@@ -2227,11 +2190,8 @@ void reset_decor_changes(void)
 
 void update_fvwm_colorset(int cset)
 {
-	if (cset == Scr.DefaultColorset)
-	{
-		Scr.flags.do_need_window_update = 1;
-		Scr.flags.has_default_color_changed = 1;
-	}
+	Scr.flags.do_need_window_update = 1;
+
 	UpdateMenuColorset(cset);
 	update_style_colorset(cset);
 	update_decors_colorset(cset);
@@ -2617,6 +2577,9 @@ void CMD_Wait(F_CMD_ARGS)
 	char *wait_string, *rest;
 	FvwmWindow *t;
 
+	if (!Scr.flags.are_windows_captured)
+		return;
+
 	/* try to get a single token */
 	rest = GetNextToken(action, &wait_string);
 	if (wait_string)
@@ -2890,20 +2853,13 @@ void CMD_ImagePath(F_CMD_ARGS)
 void CMD_IconPath(F_CMD_ARGS)
 {
 	fvwm_debug(__func__,
-		   "IconPath is deprecated since 2.3.0; use ImagePath instead.");
-	obsolete_imagepaths( action );
-
-	return;
+	    "IconPath is deprecated; use ImagePath instead.");
 }
 
 void CMD_PixmapPath(F_CMD_ARGS)
 {
 	fvwm_debug(__func__,
-		   "PixmapPath is deprecated since 2.3.0; use ImagePath"
-		   " instead." );
-	obsolete_imagepaths( action );
-
-	return;
+	    "PixmapPath is deprecated; use ImagePath instead." );
 }
 
 void CMD_LocalePath(F_CMD_ARGS)
@@ -2955,19 +2911,11 @@ void CMD_HilightColor(F_CMD_ARGS)
 	GetNextToken(action, &back);
 	if (fore && back)
 	{
-		/* TA:  FIXME:  xasprintf() */
-		action = fxmalloc(strlen(fore) + strlen(back) + 29);
-		sprintf(action, "* HilightFore %s, HilightBack %s", fore, back);
+		xasprintf(&action, "* HilightFore %s, HilightBack %s", fore, back);
 		CMD_Style(F_PASS_ARGS);
 	}
-	if (fore)
-	{
-		free(fore);
-	}
-	if (back)
-	{
-		free(back);
-	}
+	free(fore);
+	free(back);
 
 	return;
 }
@@ -2988,9 +2936,7 @@ void CMD_HilightColorset(F_CMD_ARGS)
 
 	if (action)
 	{
-		/* TA:  FIXME!  xasprintf() */
-		newaction = fxmalloc(strlen(action) + 32);
-		sprintf(newaction, "* HilightColorset %s", action);
+		xasprintf(&newaction, "* HilightColorset %s", action);
 		action = newaction;
 		CMD_Style(F_PASS_ARGS);
 		free(newaction);
@@ -3083,66 +3029,6 @@ void CMD_DefaultIcon(F_CMD_ARGS)
 	return;
 }
 
-void CMD_DefaultColorset(F_CMD_ARGS)
-{
-	int cset;
-
-	if (GetIntegerArguments(action, NULL, &cset, 1) != 1)
-	{
-		return;
-	}
-	Scr.DefaultColorset = cset;
-	if (Scr.DefaultColorset < 0)
-	{
-		Scr.DefaultColorset = -1;
-	}
-	alloc_colorset(Scr.DefaultColorset);
-	Scr.flags.do_need_window_update = 1;
-	Scr.flags.has_default_color_changed = 1;
-
-	return;
-}
-
-void CMD_DefaultColors(F_CMD_ARGS)
-{
-	char *fore = NULL;
-	char *back = NULL;
-
-	action = GetNextToken(action, &fore);
-	if (action)
-	{
-		action = GetNextToken(action, &back);
-	}
-	if (!back)
-	{
-		back = fxstrdup(DEFAULT_BACK_COLOR);
-	}
-	if (!fore)
-	{
-		fore = fxstrdup(DEFAULT_FORE_COLOR);
-	}
-	if (!StrEquals(fore, "-"))
-	{
-		PictureFreeColors(dpy, Pcmap, &Scr.StdFore, 1, 0, True);
-		Scr.StdFore = GetColor(fore);
-	}
-	if (!StrEquals(back, "-"))
-	{
-		PictureFreeColors(dpy, Pcmap, &Scr.StdBack, 3, 0, True);
-		Scr.StdBack = GetColor(back);
-		Scr.StdHilite = GetHilite(Scr.StdBack);
-		Scr.StdShadow = GetShadow(Scr.StdBack);
-	}
-	free(fore);
-	free(back);
-
-	Scr.DefaultColorset = -1;
-	Scr.flags.do_need_window_update = 1;
-	Scr.flags.has_default_color_changed = 1;
-
-	return;
-}
-
 void CMD_DefaultFont(F_CMD_ARGS)
 {
 	char *font;
@@ -3202,9 +3088,7 @@ void CMD_IconFont(F_CMD_ARGS)
 
 	if (action)
 	{
-		/* TA:  FIXME!  xasprintf() */
-		newaction = fxmalloc(strlen(action) + 16);
-		sprintf(newaction, "* IconFont %s", action);
+		xasprintf(&newaction, "* IconFont %s", action);
 		action = newaction;
 		CMD_Style(F_PASS_ARGS);
 		free(newaction);
@@ -3228,9 +3112,7 @@ void CMD_WindowFont(F_CMD_ARGS)
 
 	if (action)
 	{
-		/* TA;  FIXME!  xasprintf() */
-		newaction = fxmalloc(strlen(action) + 16);
-		sprintf(newaction, "* Font %s", action);
+		xasprintf(&newaction, "* Font %s", action);
 		action = newaction;
 		CMD_Style(F_PASS_ARGS);
 		free(newaction);
@@ -3499,8 +3381,7 @@ void CMD_SetEnv(F_CMD_ARGS)
 	{
 		szValue = fxstrdup("");
 	}
-	szPutenv = fxmalloc(strlen(szVar) + strlen(szValue) + 2);
-	sprintf(szPutenv,"%s=%s", szVar, szValue);
+	xasprintf(&szPutenv, "%s=%s", szVar, szValue);
 	flib_putenv(szVar, szPutenv);
 	free(szVar);
 	free(szPutenv);
@@ -3523,121 +3404,6 @@ void CMD_UnsetEnv(F_CMD_ARGS)
 	return;
 }
 
-void CMD_GlobalOpts(F_CMD_ARGS)
-{
-	char *opt;
-	char *replace;
-	char buf[64];
-	int i;
-	Bool is_bugopt;
-	char *optlist[] = {
-		"WindowShadeShrinks",
-		"WindowShadeScrolls",
-		"SmartPlacementIsReallySmart",
-		"SmartPlacementIsNormal",
-		"ClickToFocusDoesntPassClick",
-		"ClickToFocusPassesClick",
-		"ClickToFocusDoesntRaise",
-		"ClickToFocusRaises",
-		"MouseFocusClickDoesntRaise",
-		"MouseFocusClickRaises",
-		"NoStipledTitles",
-		"StipledTitles",
-		"CaptureHonorsStartsOnPage",
-		"CaptureIgnoresStartsOnPage",
-		"RecaptureHonorsStartsOnPage",
-		"RecaptureIgnoresStartsOnPage",
-		"ActivePlacementHonorsStartsOnPage",
-		"ActivePlacementIgnoresStartsOnPage",
-		"RaiseOverNativeWindows",
-		"IgnoreNativeWindows",
-		NULL
-	};
-	char *replacelist[] = {
-		/* These options are mapped to the Style * command */
-		NULL, /* NULL means to use "Style * <optionname>" */
-		NULL,
-		"* MinOverlapPlacement",
-		"* TileCascadePlacement",
-		"* ClickToFocusPassesClickOff",
-		"* ClickToFocusPassesClick",
-		"* ClickToFocusRaisesOff",
-		"* ClickToFocusRaises",
-		"* MouseFocusClickRaisesOff",
-		"* MouseFocusClickRaises",
-		"* StippledTitleOff",
-		"* StippledTitle",
-		NULL,
-		NULL,
-		NULL,
-		NULL,
-		"* ManualPlacementHonorsStartsOnPage",
-		"* ManualPlacementIgnoresStartsOnPage",
-		/* These options are mapped to the BugOpts command */
-		"RaiseOverNativeWindows on",
-		"RaiseOverNativeWindows off"
-	};
-
-	fvwm_debug(__func__,
-		   "The GlobalOpts command is obsolete.");
-	for (action = GetNextSimpleOption(action, &opt); opt;
-	     action = GetNextSimpleOption(action, &opt))
-	{
-		replace = NULL;
-		is_bugopt = False;
-
-		i = GetTokenIndex(opt, optlist, 0, NULL);
-		if (i > -1)
-		{
-			char *cmd;
-			char *tmp;
-
-			replace = replacelist[i];
-			if (replace == NULL)
-			{
-				replace = &(buf[0]);
-				sprintf(buf, "* %s", opt);
-			}
-			else if (*replace != '*')
-			{
-				is_bugopt = True;
-			}
-			tmp = action;
-			action = replace;
-			if (!is_bugopt)
-			{
-				CMD_Style(F_PASS_ARGS);
-				cmd = "Style";
-			}
-			else
-			{
-				CMD_BugOpts(F_PASS_ARGS);
-				cmd = "BugOpts";
-			}
-			action = tmp;
-			fvwm_debug(__func__,
-				   "Please replace 'GlobalOpts %s' with '%s %s'.",
-				   opt, cmd, replace);
-		}
-		else
-		{
-			fvwm_debug(__func__,
-				   "Unknown Global Option '%s'", opt);
-		}
-		/* should never be null, but checking anyways... */
-		if (opt)
-		{
-			free(opt);
-		}
-	}
-	if (opt)
-	{
-		free(opt);
-	}
-
-	return;
-}
-
 void CMD_BugOpts(F_CMD_ARGS)
 {
 	char *opt;
@@ -3847,7 +3613,10 @@ void CMD_BugOpts(F_CMD_ARGS)
 				Scr.bo.do_debug_randr = 0;
 				break;
 			}
-			monitor_dump_state(NULL);
+			if (Scr.bo.do_debug_randr)
+			{
+				monitor_dump_state(NULL);
+			}
 		}
 		else if (StrEquals(opt, "TransliterateUtf8"))
 		{
@@ -3896,7 +3665,6 @@ void CMD_Emulate(F_CMD_ARGS)
 
 	Scr.flags.do_need_window_update = 1;
 	Scr.flags.has_default_font_changed = 1;
-	Scr.flags.has_default_color_changed = 1;
 
 	return;
 }
@@ -3954,17 +3722,17 @@ void CMD_SetAnimation(F_CMD_ARGS)
 }
 
 /* Determine which modifiers are required with a keycode to make <keysym>. */
-static Bool FKeysymToKeycode (Display *dpy, KeySym keysym,
+static Bool FKeysymToKeycode (Display *disp, KeySym keysym,
 	unsigned int *keycode, unsigned int *modifiers)
 {
 	int m;
 
-	*keycode = XKeysymToKeycode(dpy, keysym);
+	*keycode = XKeysymToKeycode(disp, keysym);
 	*modifiers = 0;
 
 	for (m = 0; m <= 8; ++m)
 	{
-		KeySym ks = fvwm_KeycodeToKeysym(dpy, *keycode, m, 0);
+		KeySym ks = fvwm_KeycodeToKeysym(disp, *keycode, m, 0);
 		if (ks == keysym)
 		{
 			switch (m)
