@@ -19,17 +19,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
 
 #include "config.h"
 
-#include <stdio.h>
-#include <X11/Xatom.h>
-
+#include "libs/fvwm_x11.h"
 #include "libs/fvwmlib.h"
 #include "libs/Parse.h"
 #include "libs/PictureBase.h"
@@ -245,7 +242,7 @@ static void add_to_junk(Pixmap pixmap)
 {
 	struct junklist *oldjunk = junk;
 
-	junk = (struct junklist *)safemalloc(sizeof(struct junklist));
+	junk = fxmalloc(sizeof(struct junklist));
 	junk->prev = oldjunk;
 	junk->pixmap = pixmap;
 	if (!cleanup_scheduled)
@@ -253,7 +250,7 @@ static void add_to_junk(Pixmap pixmap)
 		const exec_context_t *exc;
 
 		exc = exc_create_null_context();
-		CMD_Schedule(NULL, exc, "3000 CleanupColorsets");
+		CMD_Schedule(NULL, exc, "3000 CleanupColorsets", NULL);
 		exc_destroy_context(exc);
 		cleanup_scheduled = True;
 	}
@@ -296,7 +293,7 @@ static char *get_simple_color(
 	return rest;
 }
 
-static void SafeDestroyPicture(Display *dpy, FvwmPicture *picture)
+static void SafeDestroyPicture(Display *disp, FvwmPicture *picture)
 {
 	/* have to subvert destroy picture so that it doesn't free pixmaps,
 	 * these are added to the junk list to be cleaned up after a timeout */
@@ -319,7 +316,7 @@ static void SafeDestroyPicture(Display *dpy, FvwmPicture *picture)
 		}
 	}
 	/* all that this will now do is free the colors and the name */
-	PDestroyFvwmPicture(dpy, picture);
+	PDestroyFvwmPicture(disp, picture);
 
 	return;
 }
@@ -397,7 +394,6 @@ static void reset_cs_pixmap(colorset_t *cs, GC gc)
 static void parse_pixmap(
 	Window win, GC gc, colorset_t *cs, Bool *pixmap_is_a_bitmap)
 {
-	static char *name = "parse_colorset(pixmap)";
 	FvwmPictureAttributes fpa;
 
 	/* dither */
@@ -416,7 +412,7 @@ static void parse_pixmap(
 	cs->picture = PCacheFvwmPicture(dpy, win, NULL, cs->pixmap_args, fpa);
 	if (cs->picture == NULL)
 	{
-		fvwm_msg(ERR, name, "can't load picture %s", cs->pixmap_args);
+		fvwm_debug(__func__, "can't load picture %s", cs->pixmap_args);
 		return;
 	}
 	if (cs->picture->depth != Pdepth)
@@ -467,7 +463,6 @@ static void parse_shape(Window win, colorset_t *cs, int i, char *args,
 			int *has_shape_changed)
 {
 	char *token;
-	static char *name = "parse_colorset(shape)";
 	FvwmPicture *picture;
 	FvwmPictureAttributes fpa;
 
@@ -511,11 +506,11 @@ static void parse_shape(Window win, colorset_t *cs, int i, char *args,
 	picture = PCacheFvwmPicture(dpy, win, NULL, token, fpa);
 	if (!picture)
 	{
-		fvwm_msg(ERR, name, "can't load picture %s", token);
+		fvwm_debug(__func__, "can't load picture %s", token);
 	}
 	else if (picture->depth != 1 && picture->mask == None)
 	{
-		fvwm_msg(ERR, name, "shape pixmap must be of depth 1");
+		fvwm_debug(__func__, "shape pixmap must be of depth 1");
 		SafeDestroyPicture(dpy, picture);
 	}
 	else
@@ -559,7 +554,6 @@ static void parse_simple_tint(
 	int *changed, int *percent, char *cmd)
 {
 	char *rest;
-	static char *name = "parse_colorset (tint)";
 
 	*changed = False;
 	rest = get_simple_color(args, tint, cs, supplied_color, 0, NULL);
@@ -572,9 +566,9 @@ static void parse_simple_tint(
 	}
 	else if (!GetIntegerArguments(rest, NULL, percent, 1))
 	{
-		fvwm_msg(WARN, name,
-			 "%s must have two arguments a color and an integer",
-			 cmd);
+		fvwm_debug(__func__,
+			   "%s must have two arguments a color and an integer",
+			   cmd);
 		return;
 	}
 	*changed = True;
@@ -646,7 +640,6 @@ void parse_colorset(int n, char *line)
 	Bool is_server_grabbed = False;
 	XColor color;
 	XGCValues xgcv;
-	static char *name = "parse_colorset";
 	Window win = Scr.NoFocusWin;
 	static GC gc = None;
 
@@ -783,9 +776,8 @@ void parse_colorset(int n, char *line)
 
 			if (Pdepth != DefaultDepth(dpy, (DefaultScreen(dpy))))
 			{
-				fvwm_msg(
-					ERR, name, "can't do Transparent "
-					"when root_depth!=fvwm_depth");
+				fvwm_debug(__func__, "can't do Transparent "
+					   "when root_depth!=fvwm_depth");
 				break;
 			}
 			has_pixmap_changed = True;
@@ -796,9 +788,9 @@ void parse_colorset(int n, char *line)
 		case 24: /* RootTransparent */
 			if (Pdepth != DefaultDepth(dpy, (DefaultScreen(dpy))))
 			{
-				fvwm_msg(
-					ERR, name, "can't do RootTransparent "
-					"when root_depth!=fvwm_depth");
+				fvwm_debug(__func__,
+					   "can't do RootTransparent "
+					   "when root_depth!=fvwm_depth");
 				break;
 			}
 			free_colorset_background(cs, True);
@@ -953,9 +945,8 @@ void parse_colorset(int n, char *line)
 			}
 			else
 			{
-				fvwm_msg(
-					WARN, name, "bad colorset pixmap "
-					"specifier %s %s", option, line);
+				fvwm_debug(__func__, "bad colorset pixmap "
+					   "specifier %s %s", option, line);
 			}
 			break;
 		} /* switch */
@@ -1100,8 +1091,8 @@ void parse_colorset(int n, char *line)
 
 			if (average_pix == root_pic.pixmap)
 			{
-				int w;
-				int h;
+				int w2;
+				int h2;
 				XID dummy;
 
 				MyXGrabServer(dpy);
@@ -1109,7 +1100,7 @@ void parse_colorset(int n, char *line)
 				if (!XGetGeometry(
 				    dpy, average_pix, &dummy,
 				    (int *)&dummy, (int *)&dummy,
-				    (unsigned int *)&w, (unsigned int *)&h,
+				    (unsigned int *)&w2, (unsigned int *)&h2,
 				    (unsigned int *)&dummy,
 				    (unsigned int *)&dummy))
 				{
@@ -1117,7 +1108,7 @@ void parse_colorset(int n, char *line)
 				}
 				else
 				{
-					if (w != cs->width || h != cs->height)
+					if (w2 != cs->width || h2 != cs->height)
 					{
 						average_pix = None;
 					}
@@ -1137,7 +1128,7 @@ void parse_colorset(int n, char *line)
 			XColor *colors;
 			XImage *image;
 			XImage *mask_image = None;
-			unsigned int i, j, k = 0;
+			unsigned int i2, j, k = 0;
 			unsigned long red = 0, blue = 0, green = 0;
 			unsigned long tred, tblue, tgreen;
 			double dred = 0.0, dblue = 0.0, dgreen = 0.0;
@@ -1147,7 +1138,7 @@ void parse_colorset(int n, char *line)
 			/* Note: this may allocate a lot of memory:
 			 * cs->width * cs->height * 12 and then the rest of the
 			 * procedure can take a lot of times */
-			colors = (XColor *)safemalloc(
+			colors = fxmalloc(
 				cs->width * cs->height * sizeof(XColor));
 			/* get the pixmap and mask into an image */
 			image = XGetImage(
@@ -1167,20 +1158,20 @@ void parse_colorset(int n, char *line)
 			{
 				/* only fetch the pixels that are not masked
 				 * out */
-				for (i = 0; i < cs->width; i++)
+				for (i2 = 0; i2 < cs->width; i2++)
 				{
 					for (j = 0; j < cs->height; j++)
 					{
 						if (
 							cs->mask == None ||
 							XGetPixel(
-								mask_image, i,
+								mask_image, i2,
 								j) == 0)
 						{
 							colors[k++].pixel =
 								XGetPixel(
 									image,
-									i, j);
+									i2, j);
 						}
 					}
 				}
@@ -1699,8 +1690,8 @@ void alloc_colorset(int n)
 	}
 	else
 	{
-		Colorset = (colorset_t *)saferealloc(
-			(char *)Colorset, (n + 1) * sizeof(colorset_t));
+		Colorset = fxrealloc(
+			(void *)Colorset, (n + 1), sizeof(colorset_t));
 		memset(
 			&Colorset[nColorsets], 0,
 			(n + 1 - nColorsets) * sizeof(colorset_t));
@@ -1802,7 +1793,7 @@ void update_root_transparent_colorset(Atom prop)
 
 void CMD_ReadWriteColors(F_CMD_ARGS)
 {
-	fvwm_msg(WARN, "CMD_ReadWriteColors", "ReadWriteColors is obsolete");
+	fvwm_debug(__func__, "ReadWriteColors is obsolete");
 
 	return;
 }
