@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -37,7 +36,6 @@
 #include "focus.h"
 #include "borders.h"
 #include "frame.h"
-#include "gnome.h"
 #include "ewmh.h"
 
 /* ---------------------------- local definitions -------------------------- */
@@ -169,7 +167,6 @@ static void get_resize_decor_gravities_one_axis(
 	frame_move_resize_mode axis_mode, direction_t neg_dir,
 	direction_t pos_dir, int is_moving)
 {
-
 	int title_grav;
 	int neg_grav;
 	int pos_grav;
@@ -207,7 +204,9 @@ static void get_resize_decor_gravities_one_axis(
 		ret_grav->client_grav = neg_grav;
 		break;
 	case FRAME_MR_DONT_DRAW:
+	default:
 		/* can not happen, just a dummy to keep -Wall happy */
+		ret_grav->client_grav = pos_grav;
 		break;
 	}
 	ret_grav->parent_grav = ret_grav->client_grav;
@@ -433,8 +432,11 @@ static void __frame_setup_window(
 	}
 	/* get things updated */
 	XFlush(dpy);
-	/* inform the modules of the change */
-	BroadcastConfig(M_CONFIGURE_WINDOW,fw);
+	if (is_moved || is_resized)
+	{
+		/* inform the modules of the change */
+		BroadcastConfig(M_CONFIGURE_WINDOW,fw);
+	}
 
 	return;
 }
@@ -746,6 +748,7 @@ static void frame_prepare_animation_shape(
 		rectangle tb_g;
 		XRectangle rect;
 
+		SUPPRESS_UNUSED_VAR_WARNING(rect);
 		frame_get_titlebar_dimensions_only(
 			fw, &mra->next_g, &mra->b_no_title_g, &tb_g);
 		/* windows w/ titles */
@@ -1251,7 +1254,7 @@ void frame_reshape_border(FvwmWindow *fw)
 	}
 	else
 	{
-		get_relative_geometry(new_g, new_g);
+		get_relative_geometry(fw, new_g, new_g);
 		frame_force_setup_window(
 			fw, new_g->x, new_g->y, new_g->width, new_g->height,
 			True);
@@ -1284,8 +1287,8 @@ void frame_init(void)
 			InputOutput, CopyFromParent, valuemask, &xswa);
 		if (hide_wins.w[i] == None)
 		{
-			fvwm_msg(ERR, "frame_init",
-				 "Could not create internal windows. Exiting");
+			fvwm_debug(__func__,
+				   "Could not create internal windows. Exiting");
 			MyXUngrabServer(dpy);
 			exit(1);
 		}
@@ -1730,8 +1733,7 @@ frame_move_resize_args frame_create_move_resize_args(
 	int diff;
 
 	/* set some variables */
-	mra = (mr_args_internal *)safecalloc(1, sizeof(mr_args_internal));
-	memset(mra, 0, sizeof(*mra));
+	mra = fxcalloc(1, sizeof(mr_args_internal));
 	if (mr_mode & FRAME_MR_DONT_DRAW)
 	{
 		mr_mode &= ~FRAME_MR_DONT_DRAW;
@@ -1938,13 +1940,13 @@ void frame_free_move_resize_args(
 	}
 	update_absolute_geometry(fw);
 	frame_reparent_hide_windows(Scr.NoFocusWin);
-	if (mra->w_with_focus != None)
+	if (mra->w_with_focus != None && FP_IS_LENIENT(FW_FOCUS_POLICY(fw)))
 	{
 		/* domivogt (28-Dec-1999): For some reason the XMoveResize() on
 		 * the frame window removes the input focus from the client
 		 * window.  I have no idea why, but if we explicitly restore
 		 * the focus here everything works fine. */
-		FOCUS_SET(mra->w_with_focus);
+		FOCUS_SET(mra->w_with_focus, fw);
 	}
 	if (mra->flags.do_update_shape)
 	{
@@ -2094,7 +2096,6 @@ void frame_force_setup_window(
  ****************************************************************************/
 void frame_setup_shape(FvwmWindow *fw, int w, int h, int shape_mode)
 {
-	XRectangle rect;
 	rectangle r;
 	size_borders b;
 
@@ -2123,6 +2124,8 @@ void frame_setup_shape(FvwmWindow *fw, int w, int h, int shape_mode)
 			b.top_left.height, FW_W(fw), FShapeBounding, FShapeSet);
 		if (FW_W_TITLE(fw))
 		{
+			XRectangle rect;
+
 			/* windows w/ titles */
 			r.width = w;
 			r.height = h;
@@ -2131,6 +2134,7 @@ void frame_setup_shape(FvwmWindow *fw, int w, int h, int shape_mode)
 			rect.y = r.y;
 			rect.width = r.width;
 			rect.height = r.height;
+			SUPPRESS_UNUSED_VAR_WARNING(rect);
 			FShapeCombineRectangles(
 				dpy, FW_W_FRAME(fw), FShapeBounding, 0, 0,
 				&rect, 1, FShapeUnion, Unsorted);
