@@ -1,5 +1,5 @@
 /* -*-c-*- */
-/* This module is based on Twm, but has been siginificantly modified
+/* This module is based on Twm, but has been significantly modified
  * by Rob Nation */
 /*
  *       Copyright 1988 by Evans & Sutherland Computer Corporation,
@@ -33,20 +33,22 @@
 
 /* ---------------------------- included header files ---------------------- */
 
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
-#include <X11/cursorfont.h>
-#include <X11/Intrinsic.h>
+#include "libs/fvwm_x11.h"
 #include "libs/PictureBase.h"
+#include "libs/FRender.h"
 #include "libs/Flocale.h"
+#include "libs/fvwmrect.h"
+#include "libs/FScreen.h"
 #include "window_flags.h"
 #include "condrc.h"
+#include "cmdparser.h"
 
 /* ---------------------------- global definitions ------------------------- */
 
 #ifndef WithdrawnState
 #define WithdrawnState 0
 #endif
+#define ICCCM2_UNMAP_WINDOW_PATCH 0
 
 /* ---------------------------- global macros ------------------------------ */
 
@@ -58,9 +60,9 @@
 
 /* Macro for args passed to fvwm commands... */
 #define F_CMD_ARGS \
-	cond_rc_t *cond_rc, const exec_context_t *exc, char *action
-#define F_PASS_ARGS cond_rc, exc, action
-#define FUNC_FLAGS_TYPE unsigned char
+	cond_rc_t *cond_rc, const exec_context_t *exc, char *action, cmdparser_context_t *pc
+#define F_PASS_ARGS cond_rc, exc, action, pc
+#define F_PASS_ARGS_WITH_EXC(new_exc) cond_rc, (new_exc), action, pc
 
 /* access macros */
 #define FW_W_FRAME(fw)        ((fw)->wins.frame)
@@ -77,12 +79,8 @@
 
 /* ---------------------------- forward declarations ----------------------- */
 
-struct exec_context_t;
-
-#ifdef USEDECOR
 /* definition in screen.h */
 struct FvwmDecor;
-#endif
 
 /* ---------------------------- type definitions --------------------------- */
 
@@ -93,7 +91,7 @@ struct FvwmDecor;
  * initial_state
  *   The initial window state.  By default it carries the value DontCareState.
  *   Other states can be set if
- *    - an icon is recaptured or restarted with session management
+ *    - an icon is restarted with session management
  *    - the StartIconic style is set
  *    - GNOME, EWMH, foobar hints demand that the icon starts iconic
  *   The final value is calculated in HandleMapRequestRaised().
@@ -101,7 +99,7 @@ struct FvwmDecor;
  * do_override_ppos
  *   This flag is used in PlaceWindow().  If it is set, the position requested
  *   by the program is ignored unconditionally.  This is used during the
- *   initial capture and later recapture operations.
+ *   initial capture.
  *
  * is_iconified_by_parent
  *   Preserves the information if the window is a transient window that was
@@ -110,12 +108,9 @@ struct FvwmDecor;
  *   window state flag.  Deleted afterwards.
  *
  * is_menu
- *   Set in menus.c or in the recapture code if the new window is a tear off
+ *   Set in menus.c if the new window is a tear off
  *   menu.  Such windows get special treatment in AddWindow() and events.c.
  *
- * is_recapture
- *   Set for the initial capture and later recaptures.
- *
  * default_icon_x/y
  *   The icon position that was requested by the application in the icon
  *   position hint.  May be overridden by a style (0/0 then).  Set in
@@ -138,7 +133,6 @@ typedef struct
 		unsigned do_override_ppos : 1;
 		unsigned is_iconified_by_parent : 1;
 		unsigned is_menu : 1;
-		unsigned is_recapture : 1;
 		unsigned use_initial_icon_xy : 1;
 	} flags;
 	int initial_icon_x;
@@ -156,11 +150,12 @@ typedef struct icon_boxes_struct
 	struct icon_boxes_struct *next;       /* next icon_boxes or zero */
 	unsigned int use_count;
 	int IconBox[4];                       /* x/y x/y for iconbox */
-	int IconScreen;                       /* Xinerama screen */
+	char *IconScreen;                     /* screen */
 	short IconGrid[2];                    /* x incr, y incr */
 	char IconSign[4];                     /* because of -0, need to save */
 	unsigned is_orphan : 1;
 	unsigned IconFlags : 3;               /* some bits */
+	unsigned do_free_screen : 1;
 	/* IconFill only takes 3 bits.  Defaults are top, left, vert co-ord
 	 * first eg: t l = 0,0,0; l t = 0,0,1; b r = 1,1,0 */
 #define ICONFILLBOT (1<<0)
@@ -190,6 +185,19 @@ typedef struct
 	int bottom;
 } ewmh_strut;
 
+enum border_part_cardinals
+{
+	BP_NORTH = 0,
+	BP_NE,
+	BP_EAST,
+	BP_SE,
+	BP_SOUTH,
+	BP_SW,
+	BP_WEST,
+	BP_NW,
+	BP_SIZE
+};
+
 typedef struct
 {
 	/* common flags (former flags in bits 0-12) */
@@ -215,7 +223,6 @@ typedef struct
 		unsigned do_ewmh_use_stacking_hints : 1;
 		unsigned do_ewmh_ignore_window_type : 1;
 		unsigned do_iconify_window_groups : 1;
-		unsigned do_ignore_gnome_hints : 1;
 		unsigned do_ignore_icon_boxes : 1;
 		unsigned do_ignore_restack : 1;
 		unsigned do_use_window_group_hint : 1;
@@ -430,44 +437,6 @@ struct name_condition		/* matches to namelists in this list are
 	struct name_condition *next;
 };
 
-/* Window mask for Circulate and Direction functions */
-typedef struct WindowConditionMask
-{
-	struct
-	{
-		unsigned do_accept_focus : 1;
-		unsigned do_check_desk : 1;
-		unsigned do_check_desk_and_global_page : 1;
-		unsigned do_check_desk_and_page : 1;
-		unsigned do_check_global_page : 1;
-		unsigned do_check_overlapped : 1;
-		unsigned do_check_page : 1;
-		unsigned do_not_check_screen : 1;
-		unsigned needs_current_desk : 1;
-		unsigned needs_current_desk_and_global_page : 1;
-		unsigned needs_current_desk_and_page : 1;
-		unsigned needs_current_global_page : 1;
-		unsigned needs_current_page : 1;
-#define NEEDS_ANY   0
-#define NEEDS_TRUE  1
-#define NEEDS_FALSE 2
-		unsigned needs_focus : 2;
-		unsigned needs_overlapped : 2;
-		unsigned needs_pointer : 2;
-		unsigned needs_same_layer : 1;
-		unsigned use_circulate_hit : 1;
-		unsigned use_circulate_hit_icon : 1;
-		unsigned use_circulate_hit_shaded : 1;
-		unsigned use_do_accept_focus : 1;
-	} my_flags;
-	window_flags flags;
-	window_flags flag_mask;
-	struct name_condition *name_condition;
-	int layer;
-	int placed_by_button_mask;
-	int placed_by_button_set_mask;
-} WindowConditionMask;
-
 typedef struct pl_penalty_struct
 {
 	float normal;
@@ -542,7 +511,7 @@ typedef struct style_flags
 	unsigned has_edge_delay_ms_move : 1;
 	unsigned has_edge_delay_ms_resize : 1;
 	unsigned has_edge_resistance_move : 1;
-	unsigned has_edge_resistance_xinerama_move : 1;
+	unsigned has_edge_resistance_screen_move : 1;
 	unsigned has_handle_width : 1;
 	unsigned has_icon : 1;
 	unsigned has_icon_boxes : 1;
@@ -595,6 +564,9 @@ typedef struct style_flags
 	unsigned has_placement_percentage_penalty : 1;
 	unsigned has_placement_position_string : 1;
 	unsigned has_initial_map_command_string : 1;
+	unsigned has_title_format_string : 1;
+	unsigned has_icon_title_format_string : 1;
+	unsigned initial_placement_done : 1;
 } style_flags;
 
 typedef struct style_id_t
@@ -608,6 +580,25 @@ typedef struct style_id_t
 	} flags;
 } style_id_t;
 
+typedef struct snap_attraction_t
+{
+	/* attractiveness of window edges */
+	int proximity;
+	/* mode of snap attraction */
+	int mode;
+	/* mode flags to do bit manipulation */
+	enum
+	{
+		SNAP_NONE = 0x00,
+		SNAP_WINDOWS = 0x01,
+		SNAP_ICONS = 0x02,
+		SNAP_SAME = 0x04,
+		SNAP_SCREEN = 0x08,
+		SNAP_SCREEN_WINDOWS = 0x10,
+		SNAP_SCREEN_ICONS = 0x20,
+		SNAP_SCREEN_ALL = 0x40,
+	} types;
+} snap_attraction_t;
 
 /* only style.c and add_window.c are allowed to access this struct! */
 typedef struct window_style
@@ -620,9 +611,7 @@ typedef struct window_style
 #endif
 	char *icon_name;
 	char *mini_icon_name;
-#ifdef USEDECOR
 	char *decor_name;
-#endif
 	unsigned char min_icon_width;
 	unsigned char max_icon_width;
 	unsigned char min_icon_height;
@@ -638,14 +627,10 @@ typedef struct window_style
 	signed char icon_title_relief;
 	char *icon_font;
 	char *window_font;
-	char *fore_color_name;
-	char *back_color_name;
-	char *fore_color_name_hi;
-	char *back_color_name_hi;
 	int colorset;
 	int colorset_hi;
-	int border_colorset;
-	int border_colorset_hi;
+	int border_colorset[BP_SIZE];
+	int border_colorset_hi[BP_SIZE];
 	int icon_title_colorset;
 	int icon_title_colorset_hi;
 	int icon_background_colorset;
@@ -656,36 +641,40 @@ typedef struct window_style
 	int start_desk;
 	int start_page_x;
 	int start_page_y;
-	int start_screen;
+	char *start_screen;
 	int min_window_width;
 	int min_window_height;
 	int max_window_width;
 	int max_window_height;
+	/* sizes are in terms of client window size hints */
+	bool min_window_width_is_c;
+	bool min_window_height_is_c;
+	bool max_window_width_is_c;
+	bool max_window_height_is_c;
 	int shade_anim_steps;
-#if 1 /*!!!*/
-	/* attractiveness of window edges */
-	int snap_proximity;
-	/* mode of snap attraction */
-	int snap_mode;
+	snap_attraction_t snap_attraction;
 	/* snap grid size */
 	int snap_grid_x;
 	int snap_grid_y;
 	int edge_delay_ms_move;
 	int edge_delay_ms_resize;
 	int edge_resistance_move;
-	int edge_resistance_xinerama_move;
-#endif
+	int edge_resistance_screen_move;
 	icon_boxes *icon_boxes;
 	float norm_placement_penalty;
 	pl_penalty_struct pl_penalty;
 	pl_percent_penalty_struct pl_percent_penalty;
 	char *pl_position_string;
 	char *initial_map_command_string;
+	char *title_format_string;
+	char *icon_title_format_string;
 	style_flags flags;
 	style_flags flag_default;
 	style_flags flag_mask;
 	style_flags change_mask;
 	unsigned has_style_changed : 1;
+	unsigned has_title_format_string : 1;
+	unsigned has_icon_title_format_string : 1;
 } window_style;
 
 typedef struct window_g
@@ -766,9 +755,7 @@ typedef struct FvwmWindow
 	int nr_right_buttons;
 #define BUTTON_INDEX(b) \
 	(((b) == 0) ? (NUMBER_OF_TITLE_BUTTONS - 1) : ((b) - 1))
-#ifdef USEDECOR
 	struct FvwmDecor *decor;
-#endif
 	/* is this a shaped window */
 	int wShaped;
 	Pixmap title_background_pixmap;
@@ -858,13 +845,14 @@ typedef struct FvwmWindow
 	int number_cmap_windows;
 	color_quad colors;
 	color_quad hicolors;
-	color_quad border_colors;
-	color_quad border_hicolors;
+	color_quad border_colors[BP_SIZE];
+	color_quad border_hicolors[BP_SIZE];
 
 	int cs;
 	int cs_hi;
-	int border_cs;
-	int border_cs_hi;
+	int border_cs[BP_SIZE];
+	int border_cs_hi[BP_SIZE];
+
 	int icon_title_cs;
 	int icon_title_cs_hi;
 	int icon_background_cs;
@@ -895,19 +883,14 @@ typedef struct FvwmWindow
 	int max_window_height;
 	int shade_anim_steps;
 	unsigned char grabbed_buttons;
-#if 1 /*!!!*/
-	/* attractiveness of window edges */
-	int snap_proximity;
-	/* mode of snap attraction */
-	int snap_mode;
+	snap_attraction_t snap_attraction;
 	/* snap grid size */
 	int snap_grid_x;
 	int snap_grid_y;
 	int edge_delay_ms_move;
 	int edge_delay_ms_resize;
 	int edge_resistance_move;
-	int edge_resistance_xinerama_move;
-#endif
+	int edge_resistance_screen_move;
 
 #define FM_NO_INPUT        0
 #define FM_PASSIVE         1
@@ -927,6 +910,7 @@ typedef struct FvwmWindow
 #define EWMH_WINDOW_TYPE_MENU_ID      4
 #define EWMH_WINDOW_TYPE_NORMAL_ID    5
 #define EWMH_WINDOW_TYPE_TOOLBAR_ID   6
+#define EWMH_WINDOW_TYPE_NOTIFICATION_ID 7
 	/* Note: if the type of this variable is changed, do update the
 	 * CONFIGARGSNEW macro in module_interface.c, libs/vpacket.h and too!
 	 */
@@ -952,12 +936,26 @@ typedef struct FvwmWindow
 	/* memory for the initial _NET_WM_STATE */
 	unsigned long ewmh_hint_desktop;
 
+	/* For the purposes of restoring attributes before/after a window goes
+	 * into fullscreen.
+	 */
+	struct
+	{
+		struct window_g g;
+		int is_iconified;
+		int is_shaded;
+		int was_maximized;
+	} fullscreen;
+
 	/* multi purpose scratch structure */
 	struct
 	{
 		void *p;
 		int i;
 	} scratch;
+
+	struct monitor *m;
+	struct monitor *m_prev;
 } FvwmWindow;
 
 /* ---------------------------- exported variables (globals) --------------- */
