@@ -10,17 +10,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
-/*
- * This module is mostly all new
- * by Rob Nation
- * A little of it is borrowed from ctwm.
- * Copyright 1993 Robert Nation. No restrictions are placed on this code,
- * as long as the copyright notice is preserved
- */
 /*
  *
  * fvwm icon code
@@ -35,16 +27,17 @@
 #endif
 
 #include "libs/fvwmlib.h"
-#include "libs/FScreen.h"
 #include "libs/FShape.h"
 #include "libs/Parse.h"
 #include "libs/Picture.h"
 #include "libs/Graphics.h"
 #include "libs/PictureGraphics.h"
 #include "libs/FRenderInit.h"
+#include "libs/FEvent.h"
 #include "libs/Rectangles.c"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
+#include "libs/safemalloc.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "cursor.h"
@@ -65,7 +58,6 @@
 #include "virtual.h"
 #include "decorations.h"
 #include "module_interface.h"
-#include "gnome.h"
 #include "ewmh.h"
 #include "geometry.h"
 
@@ -292,7 +284,6 @@ void GetIconPicture(FvwmWindow *fw, Bool no_icon_window)
 		icon_order[1] = 1;
 		icon_order[2] = 2;
 		icon_order[3] = 3;
-ICON_DBG((stderr,"ciw: hint order: file iwh iph '%s'\n", fw->name));
 	}
 	else if (ICON_OVERRIDE_MODE(fw) == NO_ACTIVE_ICON_OVERRIDE)
 	{
@@ -305,7 +296,6 @@ ICON_DBG((stderr,"ciw: hint order: file iwh iph '%s'\n", fw->name));
 			icon_order[1] = 2;
 			icon_order[2] = 3;
 			icon_order[3] = 0;
-ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 		}
 		else if (Scr.DefaultIcon &&
 			 fw->icon_bitmap_file == Scr.DefaultIcon)
@@ -316,7 +306,6 @@ ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 			icon_order[1] = 2;
 			icon_order[2] = 3;
 			icon_order[3] = 0;
-ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 		}
 		else
 		{
@@ -327,7 +316,6 @@ ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 			icon_order[1] = 2;
 			icon_order[2] = 0;
 			icon_order[3] = 3;
-ICON_DBG((stderr,"ciw: hint order: iwh file iph '%s'\n", fw->name));
 		}
 	}
 	else
@@ -338,7 +326,6 @@ ICON_DBG((stderr,"ciw: hint order: iwh file iph '%s'\n", fw->name));
 		icon_order[1] = 2;
 		icon_order[2] = 3;
 		icon_order[3] = 0;
-ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 	}
 
 	fw->icon_g.picture_w_g.width = 0;
@@ -358,7 +345,6 @@ ICON_DBG((stderr,"ciw: hint order: iwh iph file '%s'\n", fw->name));
 			{
 				GetIconFromFile(fw);
 			}
-ICON_DBG((stderr,"ciw: file%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":" not", fw->name));
 			break;
 		case 1:
 			/* Next, See if the app supplies its own icon window */
@@ -371,7 +357,6 @@ ICON_DBG((stderr,"ciw: file%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 			{
 				GetIconWindow(fw);
 			}
-ICON_DBG((stderr,"ciw: iwh%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":" not",fw->name));
 			break;
 		case 2:
 			/* try an ewmh icon */
@@ -382,7 +367,6 @@ ICON_DBG((stderr,"ciw: iwh%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 					SET_USE_EWMH_ICON(fw, True);
 				}
 			}
-ICON_DBG((stderr,"ciw: inh%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":" not",fw->name));
 			break;
 		case 3:
 			/* Finally, try to get icon bitmap from the
@@ -392,7 +376,6 @@ ICON_DBG((stderr,"ciw: inh%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 			{
 				GetIconBitmap(fw);
 			}
-ICON_DBG((stderr,"ciw: iph%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":" not",fw->name));
 			break;
 		default:
 			/* can't happen */
@@ -406,7 +389,7 @@ ICON_DBG((stderr,"ciw: iph%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 	{
 		int newWidth = fw->icon_g.picture_w_g.width;
 		int newHeight = fw->icon_g.picture_w_g.height;
-		Boolean resize = False;
+		Bool resize = False;
 
 		if (newWidth < fw->min_icon_width)
 		{
@@ -440,11 +423,6 @@ ICON_DBG((stderr,"ciw: iph%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
 			int force_centering = False;
 			int nrx, nry;
 
-			ICON_DBG((stderr,"ciw: Changing icon (%s) from %dx%d to"
-				  " %dx%d\n", fw->name,
-				  fw->icon_g.picture_w_g.width,
-				  fw->icon_g.picture_w_g.height,
-				  newWidth, newHeight));
 			/* Resize the icon Pixmap */
 			/* force to center if the icon has a bg */
 			if (fw->icon_background_cs >= 0 ||
@@ -519,6 +497,8 @@ ICON_DBG((stderr,"ciw: iph%s used '%s'\n", (fw->icon_g.picture_w_g.height)?"":"
  */
 static void set_icon_pixmap_background(FvwmWindow *fw)
 {
+	int cs = 0;
+
 	if (fw->iconPixmap != None &&
 	    (Pdefault || fw->iconDepth == 1 || fw->iconDepth == Pdepth ||
 	     IS_PIXMAP_OURS(fw)))
@@ -538,13 +518,13 @@ static void set_icon_pixmap_background(FvwmWindow *fw)
 			XSetWindowBackgroundPixmap(
 				dpy, FW_W_ICON_PIXMAP(fw), ParentRelative);
 		}
-		else if (Scr.DefaultColorset >= 0)
+		else
 		{
 			SetWindowBackground(
 				dpy, FW_W_ICON_PIXMAP(fw),
 				fw->icon_g.picture_w_g.width,
 				fw->icon_g.picture_w_g.height,
-				&Colorset[Scr.DefaultColorset], Pdepth,
+				&Colorset[cs], Pdepth,
 				Scr.StdGC, False);
 		}
 	}
@@ -565,6 +545,7 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 	Window old_icon_pixmap_w;
 	Window old_icon_w;
 	Bool is_old_icon_shaped = IS_ICON_SHAPED(fw);
+	int cs = 0;
 
 	old_icon_w = FW_W_ICON_TITLE(fw);
 	old_icon_pixmap_w = (IS_ICON_OURS(fw)) ? FW_W_ICON_PIXMAP(fw) : None;
@@ -620,7 +601,7 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 	valuemask = CWColormap | CWBorderPixel | CWBackPixel | CWCursor |
 		CWEventMask;
 	attributes.colormap = Pcmap;
-	attributes.background_pixel = Scr.StdBack;
+	attributes.background_pixel = Colorset[cs].bg;
 	attributes.cursor = Scr.FvwmCursors[CRS_DEFAULT];
 	attributes.border_pixel = 0;
 	attributes.event_mask = XEVMASK_ICONW;
@@ -654,14 +635,11 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 				fw->icon_g.title_w_g.height);
 		}
 	}
-	if (Scr.DefaultColorset >= 0)
-	{
-		SetWindowBackground(
-			dpy, FW_W_ICON_TITLE(fw), fw->icon_g.title_w_g.width,
-			fw->icon_g.title_w_g.height,
-			&Colorset[Scr.DefaultColorset], Pdepth, Scr.StdGC,
-			False);
-	}
+	SetWindowBackground(
+		dpy, FW_W_ICON_TITLE(fw), fw->icon_g.title_w_g.width,
+		fw->icon_g.title_w_g.height,
+		&Colorset[cs], Pdepth, Scr.StdGC,
+		False);
 
 	/*
 	 * create the icon picture window
@@ -758,6 +736,7 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 				off = abs(fw->icon_background_relief) +
 					fw->icon_background_padding;
 			}
+			SUPPRESS_UNUSED_VAR_WARNING(off);
 			FShapeCombineMask(
 				dpy, FW_W_ICON_PIXMAP(fw), FShapeBounding, off,
 				off, fw->icon_maskPixmap, FShapeSet);
@@ -772,6 +751,7 @@ void CreateIconWindow(FvwmWindow *fw, int def_x, int def_y)
 			r.y = 0;
 			r.width = fw->icon_g.picture_w_g.width;
 			r.height = fw->icon_g.picture_w_g.height;
+			SUPPRESS_UNUSED_VAR_WARNING(r);
 			FShapeCombineRectangles(
 				dpy, FW_W_ICON_PIXMAP(fw), FShapeBounding, 0,
 				0, &r, 1, FShapeSet, 0);
@@ -878,9 +858,8 @@ void DrawIconTitleWindow(
 		{
 			x_title_w = fw->icon_g.picture_w_g.x -
 				(w_title_w - fw->icon_g.picture_w_g.width) / 2;
-			FScreenGetScrRect(
-				NULL, FSCREEN_CURRENT,
-				&sx, &sy, &sw, &sh);
+			FScreenGetScrRect(NULL, FSCREEN_CURRENT,
+					  &sx, &sy, &sw, &sh);
 			/* start keep label on screen. dje 8/7/97 */
 			if (x_title_w < sx) {
 				/* if new loc neg (off left edge) */
@@ -1254,7 +1233,7 @@ void DrawIconWindow(
 	int co_title_cs = -1;
 	int is_expanded = IS_ICON_ENTERED(fw);
 
-	if (IS_ICON_SUPPRESSED(fw) || (pev && fw->Desk != Scr.CurrentDesk))
+	if (IS_ICON_SUPPRESSED(fw) || (pev && fw->Desk != fw->m->virtual_scr.CurrentDesk))
 	{
 		return;
 	}
@@ -1378,7 +1357,9 @@ void DrawIconWindow(
 		{
 			if (!pev)
 			{
-				flush_expose(FW_W_ICON_TITLE(fw));
+				FCheckWeedTypedWindowEvents(
+					dpy, FW_W_ICON_TITLE(fw), Expose,
+					NULL);
 			}
 			DrawIconTitleWindow(
 				fw, pev, BackColor, Shadow, Relief, cs,
@@ -1495,7 +1476,9 @@ void DrawIconWindow(
 		{
 			if (!pev)
 			{
-				flush_expose(FW_W_ICON_PIXMAP(fw));
+				FCheckWeedTypedWindowEvents(
+					dpy, FW_W_ICON_PIXMAP(fw), Expose,
+					NULL);
 			}
 			DrawIconPixmapWindow(
 				fw, reset_bg, pev, Shadow, Relief, cs);
@@ -1544,13 +1527,11 @@ void ChangeIconPixmap(FvwmWindow *fw)
 
 	if (!IS_ICONIFIED(fw))
 	{
-		ICON_DBG((stderr,"hpn: postpone icon change '%s'\n", fw->name));
 		/* update the icon later when application is iconified */
 		SET_HAS_ICON_CHANGED(fw, 1);
 	}
 	else if (IS_ICONIFIED(fw))
 	{
-		ICON_DBG((stderr,"hpn: applying new icon '%s'\n", fw->name));
 		SET_ICONIFIED(fw, 0);
 		SET_ICON_UNMAPPED(fw, 0);
 		get_icon_geometry(fw, &g);
@@ -1570,7 +1551,7 @@ void ChangeIconPixmap(FvwmWindow *fw)
 		{
 			LowerWindow(fw, False);
 			AutoPlaceIcon(fw, NULL, True);
-			if (fw->Desk == Scr.CurrentDesk)
+			if (fw->Desk == fw->m->virtual_scr.CurrentDesk)
 			{
 				if (FW_W_ICON_TITLE(fw))
 				{
@@ -1650,44 +1631,44 @@ void AutoPlaceIcon(
    * visible on the current page. */
   if (IS_ICON_STICKY_ACROSS_DESKS(t) || IS_STICKY_ACROSS_DESKS(t))
   {
-    t->Desk = Scr.CurrentDesk;
+    t->Desk = t->m->virtual_scr.CurrentDesk;
   }
   if (IS_ICON_STICKY_ACROSS_PAGES(t) || IS_STICKY_ACROSS_PAGES(t))
   {
     base_x = 0;
     base_y = 0;
     /*Also, if its a stickyWindow, put it on the current page! */
-    new_x = t->g.frame.x % Scr.MyDisplayWidth;
-    new_y = t->g.frame.y % Scr.MyDisplayHeight;
+    new_x = t->g.frame.x % monitor_get_all_widths();
+    new_y = t->g.frame.y % monitor_get_all_heights();
     if (new_x + t->g.frame.width <= 0)
-      new_x += Scr.MyDisplayWidth;
+      new_x += monitor_get_all_widths();
     if (new_y + t->g.frame.height <= 0)
-      new_y += Scr.MyDisplayHeight;
+      new_y += monitor_get_all_heights();
     frame_setup_window(
 	    t, new_x, new_y, t->g.frame.width, t->g.frame.height, False);
   }
-  else if (IsRectangleOnThisPage(&(t->g.frame), t->Desk))
+  else if (IsRectangleOnThisPage(t->m, &(t->g.frame), t->Desk))
   {
     base_x = 0;
     base_y = 0;
   }
   else
   {
-    base_x = ((t->g.frame.x + Scr.Vx + (t->g.frame.width >> 1)) /
-      Scr.MyDisplayWidth) * Scr.MyDisplayWidth;
-    base_y= ((t->g.frame.y + Scr.Vy + (t->g.frame.height >> 1)) /
-      Scr.MyDisplayHeight) * Scr.MyDisplayHeight;
+    base_x = ((t->g.frame.x + t->m->virtual_scr.Vx + (t->g.frame.width >> 1)) /
+      monitor_get_all_widths()) * monitor_get_all_widths();
+    base_y= ((t->g.frame.y + t->m->virtual_scr.Vy + (t->g.frame.height >> 1)) /
+      monitor_get_all_heights()) * monitor_get_all_heights();
     /* limit icon position to desktop */
-    if (base_x > Scr.VxMax)
-      base_x = Scr.VxMax;
+    if (base_x > t->m->virtual_scr.VxMax)
+      base_x = t->m->virtual_scr.VxMax;
     if (base_x < 0)
       base_x = 0;
-    if (base_y > Scr.VyMax)
-      base_y = Scr.VyMax;
+    if (base_y > t->m->virtual_scr.VyMax)
+      base_y = t->m->virtual_scr.VyMax;
     if (base_y < 0)
       base_y = 0;
-    base_x -= Scr.Vx;
-    base_y -= Scr.Vy;
+    base_x -= t->m->virtual_scr.Vx;
+    base_y -= t->m->virtual_scr.Vy;
   }
   if (IS_ICON_MOVED(t) ||
       (win_opts != NULL && win_opts->flags.use_initial_icon_xy))
@@ -1706,15 +1687,15 @@ void AutoPlaceIcon(
     dy = g.y;
 
     /* just make sure the icon is on this page */
-    g.x = g.x % Scr.MyDisplayWidth + base_x;
-    g.y = g.y % Scr.MyDisplayHeight + base_y;
+    g.x = g.x % monitor_get_all_widths() + base_x;
+    g.y = g.y % monitor_get_all_heights() + base_y;
     if (g.x < 0)
     {
-      g.x += Scr.MyDisplayWidth;
+      g.x += monitor_get_all_widths();
     }
     if (g.y < 0)
     {
-      g.y += Scr.MyDisplayHeight;
+      g.y += monitor_get_all_heights();
     }
     dx = g.x - dx;
     dy = g.y - dy;
@@ -1774,7 +1755,7 @@ void AutoPlaceIcon(
     dimension dim[3];                   /* space for work, 1st, 2nd dimen */
     icon_boxes *icon_boxes_ptr;         /* current icon box */
     int i;                              /* index for inner/outer loop data */
-    fscreen_scr_arg fscr;
+    fscreen_scr_arg *fscr;
     rectangle ref;
     rectangle g;
 
@@ -1788,8 +1769,9 @@ void AutoPlaceIcon(
 #define HRZ_FILL icon_boxes_ptr->IconFlags & ICONFILLHRZ
 
     /* needed later */
-    fscr.xypos.x = t->g.frame.x + (t->g.frame.width / 2) - base_x;
-    fscr.xypos.y = t->g.frame.y + (t->g.frame.height / 2) - base_y;
+    fscr = fxcalloc(1, sizeof *fscr);
+    fscr->xypos.x = t->g.frame.x + (t->g.frame.width / 2) - base_x;
+    fscr->xypos.y = t->g.frame.y + (t->g.frame.height / 2) - base_y;
     get_icon_geometry(t, &g);
     /* unnecessary copy of width */
     width = g.width;
@@ -1809,12 +1791,8 @@ void AutoPlaceIcon(
 	break;
       }
       /* get the screen dimensions for the icon box */
-      if (icon_boxes_ptr->IconScreen == FSCREEN_CURRENT)
-	fscr.mouse_ev = NULL;
-      FScreenGetScrRect(
-	&fscr,
-	icon_boxes_ptr->IconScreen,
-	&ref.x, &ref.y, &ref.width, &ref.height);
+      FScreenGetScrRect(fscr, FSCREEN_CURRENT,
+		        &ref.x, &ref.y, &ref.width, &ref.height);
       dim[1].screen_offset = ref.y;
       dim[1].screen_dimension = ref.height;
       dim[2].screen_offset = ref.x;
@@ -1961,7 +1939,7 @@ void AutoPlaceIcon(
 	  }
 
 	  /* this may be a good location */
-	  if (FScreenIsRectangleOnScreen(&fscr, FSCREEN_XYPOS, &ref))
+	  if (FScreenIsRectangleOnScreen(fscr, FSCREEN_XYPOS, &ref))
 	  {
 	    loc_ok = True;
 	  }
@@ -1976,18 +1954,18 @@ void AutoPlaceIcon(
 	    /* test overlap */
 	    if (test_fw->Desk == t->Desk)
 	    {
-	      rectangle g;
+	      rectangle g2;
 
 	      if ((IS_ICONIFIED(test_fw)) &&
 		 (!IS_TRANSIENT(test_fw) ||
 		  !IS_ICONIFIED_BY_PARENT(test_fw)) &&
 		 (FW_W_ICON_TITLE(test_fw)||FW_W_ICON_PIXMAP(test_fw)) &&
 		 (test_fw != t)) {
-		get_icon_geometry(test_fw, &g);
-		if ((g.x<(real_x+width+MIN_ICON_BOX_DIST))&&
-		   ((g.x+g.width+MIN_ICON_BOX_DIST) > real_x)&&
-		   (g.y<(real_y+height+MIN_ICON_BOX_DIST))&&
-		   ((g.y+g.height + MIN_ICON_BOX_DIST)>real_y))
+		get_icon_geometry(test_fw, &g2);
+		if ((g2.x<(real_x+width+MIN_ICON_BOX_DIST))&&
+		   ((g2.x+g2.width+MIN_ICON_BOX_DIST) > real_x)&&
+		   (g2.y<(real_y+height+MIN_ICON_BOX_DIST))&&
+		   ((g2.y+g2.height + MIN_ICON_BOX_DIST)>real_y))
 		{
 		  /* don't accept this location */
 		  loc_ok = False;
@@ -2014,6 +1992,8 @@ void AutoPlaceIcon(
     set_icon_position(t, real_x, real_y);
     broadcast_icon_geometry(t, True);
     do_move_icon = True;
+    free(fscr);
+
   }
   if (do_move_icon && do_move_immediately)
   {
@@ -2046,7 +2026,7 @@ do_all_iconboxes(FvwmWindow *t, icon_boxes **icon_boxes_ptr)
 		 * screen, uses an 80x80 grid, and fills top-bottom,
 		 * left-right */
 		FScreenGetScrRect(NULL, FSCREEN_PRIMARY, &sx, &sy, &sw, &sh);
-		global_icon_box_ptr = calloc(1, sizeof(icon_boxes));
+		global_icon_box_ptr = fxcalloc(1, sizeof(icon_boxes));
 		global_icon_box_ptr->IconBox[0] = sx;
 		global_icon_box_ptr->IconBox[1] = sy;
 		global_icon_box_ptr->IconBox[2] = sx + sw;
@@ -2122,7 +2102,7 @@ static void GetIconFromFile(FvwmWindow *fw)
 		&fw->iconDepth, &fw->icon_nalloc_pixels, &fw->icon_alloc_pixels,
 		&fw->icon_no_limit, fpa))
 	{
-		fvwm_msg(ERR, "GetIconFromFile", "Failed to load %s", path);
+		fvwm_debug(__func__, "Failed to load %s", path);
 		free(path);
 		return;
 	}
@@ -2157,10 +2137,9 @@ static void GetIconWindow(FvwmWindow *fw)
 		    (unsigned int*)&w, (unsigned int*)&h,(unsigned int*)&bw,
 		    (unsigned int*)&JunkDepth) == 0)
 	{
-		fvwm_msg(
-			ERR,"GetIconWindow",
-			"Window '%s' has a bad icon window! Ignoring icon"
-			" window.", fw->name.name);
+		fvwm_debug(__func__,
+			   "Window '%s' has a bad icon window! Ignoring icon"
+			   " window.", fw->name.name);
 		/* disable the icon window hint */
 		fw->wmhints->icon_window = None;
 		fw->wmhints->flags &= ~IconWindowHint;
@@ -2212,10 +2191,9 @@ static void GetIconBitmap(FvwmWindow *fw)
 		    (unsigned int*)&width, (unsigned int*)&height,
 		    (unsigned int*)&JunkBW, (unsigned int*)&depth))
 	{
-		fvwm_msg(
-			ERR,"GetIconBitmap",
-			"Window '%s' has a bad icon pixmap! Ignoring icon.",
-			fw->name.name);
+		fvwm_debug(__func__,
+			   "Window '%s' has a bad icon pixmap! Ignoring icon.",
+			   fw->name.name);
 		/* disable icon pixmap hint */
 		fw->wmhints->icon_pixmap = None;
 		fw->wmhints->flags &= ~IconPixmapHint;
@@ -2226,12 +2204,11 @@ static void GetIconBitmap(FvwmWindow *fw)
 	if (depth != 1 && depth != Pdepth &&
 	    depth != DefaultDepth(dpy,Scr.screen))
 	{
-		fvwm_msg(
-			ERR, "GetIconBitmap",
-			"Window '%s' has a bad icon bitmap depth %d (should"
-			" be 1, %d or %d)! Ignoring icon bitmap.",
-			fw->name.name, depth, Pdepth,
-			DefaultDepth(dpy,Scr.screen));
+		fvwm_debug(__func__,
+			   "Window '%s' has a bad icon bitmap depth %d (should"
+			   " be 1, %d or %d)! Ignoring icon bitmap.",
+			   fw->name.name, depth, Pdepth,
+			   DefaultDepth(dpy,Scr.screen));
 		/* disable icon pixmap hint */
 		fw->wmhints->icon_pixmap = None;
 		fw->wmhints->flags &= ~IconPixmapHint;
@@ -2339,7 +2316,7 @@ void DeIconify(FvwmWindow *fw)
 			XFlush(dpy);
 			/* End AS */
 			XMapWindow(dpy, FW_W(t));
-			if (t->Desk == Scr.CurrentDesk)
+			if (t->Desk == t->m->virtual_scr.CurrentDesk)
 			{
 				rectangle r;
 
@@ -2349,8 +2326,8 @@ void DeIconify(FvwmWindow *fw)
 				 * code already takes care of keeping the frame
 				 * geometry up to date */
 				update_absolute_geometry(t);
-				if (IsRectangleOnThisPage(&r, t->Desk) &&
-				    !IsRectangleOnThisPage(
+				if (IsRectangleOnThisPage(t->m, &r, t->Desk) &&
+				    !IsRectangleOnThisPage(t->m,
 					    &(t->g.frame), t->Desk))
 				{
 					/* Make sure we keep it on screen when
@@ -2358,11 +2335,11 @@ void DeIconify(FvwmWindow *fw)
 					t->g.frame.x -=
 						truncate_to_multiple(
 							t->g.frame.x,
-							Scr.MyDisplayWidth);
+							monitor_get_all_widths());
 					t->g.frame.y -=
 						truncate_to_multiple(
 							t->g.frame.y,
-							Scr.MyDisplayHeight);
+							monitor_get_all_heights());
 					XMoveWindow(
 						dpy, FW_W_FRAME(t),
 						t->g.frame.x, t->g.frame.y);
@@ -2404,7 +2381,7 @@ void DeIconify(FvwmWindow *fw)
 					(long)icon_rect.height);
 			}
 			XMapWindow(dpy, FW_W_PARENT(t));
-			if (t->Desk == Scr.CurrentDesk)
+			if (t->Desk == t->m->virtual_scr.CurrentDesk)
 			{
 				XMapWindow(dpy, FW_W_FRAME(t));
 				SET_MAP_PENDING(t, 1);
@@ -2442,7 +2419,6 @@ void DeIconify(FvwmWindow *fw)
 		SetFocusWindow(fw, True, FOCUS_SET_FORCE);
 	}
 	focus_grab_buttons_on_layer(fw->layer);
-	GNOME_SetWinArea(fw);
 
 	return;
 }
@@ -2618,9 +2594,9 @@ void Iconify(FvwmWindow *fw, initial_window_options_t *win_opts)
 	}
 	if (IS_ICON_STICKY_ACROSS_DESKS(fw) || IS_STICKY_ACROSS_DESKS(fw))
 	{
-		fw->Desk = Scr.CurrentDesk;
+		fw->Desk = fw->m->virtual_scr.CurrentDesk;
 	}
-	if (fw->Desk == Scr.CurrentDesk)
+	if (fw->Desk == fw->m->virtual_scr.CurrentDesk)
 	{
 		if (FW_W_ICON_TITLE(fw) != None)
 		{
