@@ -55,233 +55,6 @@ static MenuStyle *default_menu_style;
 
 /* ---------------------------- local functions ---------------------------- */
 
-static void menustyle_free_face(MenuFace *mf)
-{
-	switch (mf->type)
-	{
-	case GradientMenu:
-		if (Pdepth <= 8 && mf->u.grad.npixels > 0 &&
-		    !mf->u.grad.do_dither)
-		{
-			Pixel *p;
-			int i;
-
-			p = fxmalloc(mf->u.grad.npixels * sizeof(Pixel));
-			for(i=0; i < mf->u.grad.npixels; i++)
-			{
-				p[i] = mf->u.grad.xcs[i].pixel;
-			}
-			PictureFreeColors(
-				dpy, Pcmap, p, mf->u.grad.npixels, 0, False);
-			free(p);
-		}
-		free(mf->u.grad.xcs);
-		mf->u.grad.xcs = NULL;
-		break;
-	case PixmapMenu:
-	case TiledPixmapMenu:
-		if (mf->u.p)
-		{
-			PDestroyFvwmPicture(dpy, mf->u.p);
-		}
-		mf->u.p = NULL;
-		break;
-	case SolidMenu:
-		fvwmlib_free_colors(dpy, &mf->u.back, 1, True);
-	default:
-		break;
-	}
-	mf->type = SimpleMenu;
-
-	return;
-}
-
-static void menustyle_copy_face(MenuFace *destmf, MenuFace *origmf)
-{
-	FvwmPictureAttributes fpa;
-	int i;
-
-	menustyle_free_face(destmf);
-	destmf->type = SimpleMenu;
-	switch (origmf->type)
-	{
-	case SolidMenu:
-		fvwmlib_copy_color(
-			dpy, &destmf->u.back, &origmf->u.back, False, True);
-		destmf->type = SolidMenu;
-		break;
-	case GradientMenu:
-		destmf->u.grad.xcs = fxmalloc(sizeof(XColor) *
-					     origmf->u.grad.npixels);
-		memcpy(destmf->u.grad.xcs,
-		       origmf->u.grad.xcs,
-		       sizeof(XColor) * origmf->u.grad.npixels);
-		for (i = 0; i<origmf->u.grad.npixels;i++)
-		{
-			fvwmlib_clone_color(origmf->u.grad.xcs[i].pixel);
-		}
-
-		destmf->u.grad.npixels = origmf->u.grad.npixels;
-		destmf->u.grad.do_dither = origmf->u.grad.do_dither;
-		destmf->type = GradientMenu;
-		destmf->gradient_type = origmf->gradient_type;
-		break;
-	case PixmapMenu:
-	case TiledPixmapMenu:
-		fpa.mask = (Pdepth <= 8)?  FPAM_DITHER:0;
-
-		if (destmf->u.p)
-			destmf->u.p = NULL;
-
-		if (origmf->u.p)
-			destmf->u.p = PCacheFvwmPicture(
-				dpy, Scr.NoFocusWin, NULL, origmf->u.p->name,
-				fpa);
-
-		destmf->type = origmf->type;
-		break;
-	default:
-		break;
-	}
-}
-
-/*
- *
- * Reads a menu face line into a structure (veliaa@rpi.edu)
- *
- */
-static Bool menustyle_parse_face(char *s, MenuFace *mf, int verbose)
-{
-	char *style;
-	char *token;
-	char *action = s;
-	FvwmPictureAttributes fpa;
-
-	s = GetNextToken(s, &style);
-	if (style && strncasecmp(style, "--", 2) == 0)
-	{
-		free(style);
-		return True;
-	}
-
-	menustyle_free_face(mf);
-	mf->type = SimpleMenu;
-
-	/* determine menu style */
-	if (!style)
-	{
-		return True;
-	}
-	else if (StrEquals(style,"Solid"))
-	{
-		s = GetNextToken(s, &token);
-		if (token)
-		{
-			mf->type = SolidMenu;
-			mf->u.back = GetColor(token);
-			free(token);
-		}
-		else
-		{
-			if (verbose)
-			{
-				fvwm_debug(__func__,
-					   "no color given for Solid face type:"
-					   " %s", action);
-			}
-			free(style);
-			return False;
-		}
-	}
-
-	else if (StrEquals(style+1, "Gradient"))
-	{
-		char **s_colors;
-		int npixels, nsegs, *perc;
-		XColor *xcs;
-
-		if (!IsGradientTypeSupported(style[0]))
-		{
-			return False;
-		}
-
-		/* translate the gradient string into an array of colors etc */
-		npixels = ParseGradient(s, NULL, &s_colors, &perc, &nsegs);
-		if (npixels <= 0)
-		{
-			return False;
-		}
-		/* dither ? */
-		mf->u.grad.do_dither = False;
-		if (Pdepth <= 8)
-		{
-			mf->u.grad.do_dither = True;
-		}
-		/* grab the colors */
-		xcs = AllocAllGradientColors(
-			s_colors, perc, nsegs, npixels, mf->u.grad.do_dither);
-		if (xcs == None)
-		{
-			return False;
-		}
-
-		mf->u.grad.xcs = xcs;
-		mf->u.grad.npixels = npixels;
-		mf->type = GradientMenu;
-		mf->gradient_type = toupper(style[0]);
-	}
-
-	else if (StrEquals(style,"Pixmap") || StrEquals(style,"TiledPixmap"))
-	{
-		s = GetNextToken(s, &token);
-		fpa.mask = (Pdepth <= 8)?  FPAM_DITHER:0;
-		if (token)
-		{
-			mf->u.p = PCacheFvwmPicture(
-				dpy, Scr.NoFocusWin, NULL, token, fpa);
-			if (mf->u.p == NULL)
-			{
-				if (verbose)
-				{
-					fvwm_debug(__func__,
-						   "couldn't load pixmap %s",
-						   token);
-				}
-				free(token);
-				free(style);
-				return False;
-			}
-			free(token);
-			mf->type = (StrEquals(style,"TiledPixmap")) ?
-				TiledPixmapMenu : PixmapMenu;
-		}
-		else
-		{
-			if (verbose)
-			{
-				fvwm_debug(__func__,
-					   "missing pixmap name for style %s",
-					   style);
-			}
-			free(style);
-			return False;
-		}
-	}
-	else
-	{
-		if (verbose)
-		{
-			fvwm_debug(__func__, "unknown style %s: %s",
-				   style, action);
-		}
-		free(style);
-		return False;
-	}
-	free(style);
-
-	return True;
-}
-
 static void parse_vertical_spacing_line(
 	char *args, signed char *above, signed char *below,
 	signed char above_default, signed char below_default)
@@ -324,82 +97,16 @@ static void parse_vertical_margins_line(
 	return;
 }
 
-static MenuStyle *menustyle_parse_old_style(F_CMD_ARGS)
-{
-	char *buffer, *rest;
-	char *fore, *back, *stipple, *font, *style, *animated;
-	MenuStyle *ms = NULL;
-
-	rest = GetNextToken(action,&fore);
-	rest = GetNextToken(rest,&back);
-	rest = GetNextToken(rest,&stipple);
-	rest = GetNextToken(rest,&font);
-	rest = GetNextToken(rest,&style);
-	rest = GetNextToken(rest,&animated);
-
-	if (!fore || !back || !stipple || !font || !style)
-	{
-		fvwm_debug(__func__,
-			   "error in %s style specification", action);
-	}
-	else
-	{
-		buffer = (char *)alloca(strlen(action) + 100);
-		sprintf(buffer,
-			"* \"%s\", Foreground \"%s\", Background \"%s\", "
-			"Greyed \"%s\", Font \"%s\", \"%s\"",
-			style, fore, back, stipple, font,
-			(animated && StrEquals(animated, "anim")) ?
-			"Animation" : "AnimationOff");
-		fvwm_debug(__func__,
-			   "The old MenuStyle syntax has been deprecated.  "
-			   "Use 'MenuStyle %s' instead of 'MenuStyle %s'\n",
-			   buffer, action);
-		action = buffer;
-		ms = menustyle_parse_style(F_PASS_ARGS);
-	}
-
-	if (fore)
-	{
-		free(fore);
-	}
-	if (back)
-	{
-		free(back);
-	}
-	if (stipple)
-	{
-		free(stipple);
-	}
-	if (font)
-	{
-		free(font);
-	}
-	if (style)
-	{
-		free(style);
-	}
-	if (animated)
-	{
-		free(animated);
-	}
-
-	return ms;
-}
-
 static int menustyle_get_styleopt_index(char *option)
 {
 	char *optlist[] = {
 		"fvwm", "mwm", "win",
-		"Foreground", "Background", "Greyed",
-		"HilightBack", "HilightBackOff",
-		"ActiveFore", "ActiveForeOff",
+		"HilightBack", "ActiveFore",
 		"Hilight3DThick", "Hilight3DThin", "Hilight3DOff",
-		"Animation", "AnimationOff",
+		"Animation",
 		"Font",
-		"MenuFace",
 		"PopupDelay", "PopupOffset",
-		"TitleWarp", "TitleWarpOff",
+		"TitleWarp",
 		"TitleUnderlines0", "TitleUnderlines1", "TitleUnderlines2",
 		"SeparatorsLong", "SeparatorsShort",
 		"TrianglesSolid", "TrianglesRelief",
@@ -412,7 +119,7 @@ static int menustyle_get_styleopt_index(char *option)
 		"BorderWidth",
 		"Hilight3DThickness",
 		"ItemFormat",
-		"AutomaticHotkeys", "AutomaticHotkeysOff",
+		"AutomaticHotkeys",
 		"VerticalItemSpacing",
 		"VerticalTitleSpacing",
 		"MenuColorset", "ActiveColorset", "GreyedColorset",
@@ -427,6 +134,7 @@ static int menustyle_get_styleopt_index(char *option)
 		"TitleFont",
 		"VerticalMargins",
 		"UniqueHotkeyActivatesImmediate",
+		"Translucent",
 		NULL
 	};
 
@@ -462,7 +170,6 @@ void menustyle_free(MenuStyle *ms)
 	{
 		return;
 	}
-	menustyle_free_face(&ST_FACE(ms));
 	if (FORE_GC(ST_MENU_INACTIVE_GCS(ms)))
 	{
 		XFreeGC(dpy, FORE_GC(ST_MENU_INACTIVE_GCS(ms)));
@@ -532,24 +239,6 @@ void menustyle_free(MenuStyle *ms)
 		free(ST_ITEM_FORMAT(ms));
 	}
 
-	fvwmlib_free_colors(dpy, &ST_MENU_COLORS(ms).back,1,True);
-	fvwmlib_free_colors(dpy, &ST_MENU_COLORS(ms).fore,1,True);
-	if (ST_HAS_STIPPLE_FORE(ms))
-	{
-		fvwmlib_free_colors(
-			dpy, &ST_MENU_STIPPLE_COLORS(ms).fore,1,True);
-	}
-	if (ST_HAS_ACTIVE_BACK(ms))
-	{
-		fvwmlib_free_colors(
-			dpy, &ST_MENU_ACTIVE_COLORS(ms).back,1,True);
-	}
-	if (ST_HAS_ACTIVE_FORE(ms))
-	{
-		fvwmlib_free_colors(
-			dpy, &ST_MENU_ACTIVE_COLORS(ms).fore,1,True);
-	}
-
 	while (ST_NEXT_STYLE(before) != ms)
 	{
 		/* Not too many checks, may segfault in race conditions */
@@ -583,10 +272,6 @@ void menustyle_update(MenuStyle *ms)
 {
 	XGCValues gcv;
 	unsigned long gcm;
-	color_quad c_inactive;
-	color_quad c_active;
-	color_quad c_stipple;
-	color_quad c_title;
 	colorset_t *menu_cs = &Colorset[ST_CSET_MENU(ms)];
 	colorset_t *active_cs = &Colorset[ST_CSET_ACTIVE(ms)];
 	colorset_t *greyed_cs = &Colorset[ST_CSET_GREYED(ms)];
@@ -607,110 +292,6 @@ void menustyle_update(MenuStyle *ms)
 	{
 		ST_PTITLEFONT(ms) = ST_PSTDFONT(ms);
 	}
-	/* calculate colors based on foreground */
-	if (!ST_HAS_ACTIVE_FORE(ms))
-	{
-		ST_MENU_ACTIVE_COLORS(ms).fore = ST_MENU_COLORS(ms).fore;
-	}
-	/* calculate colors based on background */
-	if (!ST_HAS_ACTIVE_BACK(ms))
-	{
-		ST_MENU_ACTIVE_COLORS(ms).back = ST_MENU_COLORS(ms).back;
-	}
-	if (!ST_HAS_STIPPLE_FORE(ms))
-	{
-		ST_MENU_STIPPLE_COLORS(ms).fore = ST_MENU_COLORS(ms).back;
-	}
-	ST_MENU_STIPPLE_COLORS(ms).back = ST_MENU_COLORS(ms).back;
-	/* prepare colours for changing the gcs */
-	if (ST_HAS_MENU_CSET(ms))
-	{
-		c_inactive.fore = menu_cs->fg;
-		c_inactive.back = menu_cs->bg;
-		c_inactive.hilight = menu_cs->hilite;
-		c_inactive.shadow = menu_cs->shadow;
-	}
-	else
-	{
-		c_inactive.fore = ST_MENU_COLORS(ms).fore;
-		c_inactive.back = ST_MENU_COLORS(ms).back;
-		if (Pdepth > 2)
-		{
-			c_inactive.hilight = GetHilite(ST_MENU_COLORS(ms).back);
-			c_inactive.shadow = GetShadow(ST_MENU_COLORS(ms).back);
-		}
-		else
-		{
-			c_inactive.hilight = GetColor(DEFAULT_HILIGHT_COLOR);
-			c_inactive.shadow = GetColor(DEFAULT_SHADOW_COLOR);
-		}
-	}
-	if (ST_HAS_ACTIVE_CSET(ms))
-	{
-		c_active.fore = active_cs->fg;
-		c_active.back = active_cs->bg;
-		c_active.hilight = active_cs->hilite;
-		c_active.shadow = active_cs->shadow;
-	}
-	else
-	{
-		c_active.fore = ST_MENU_ACTIVE_COLORS(ms).fore;
-		c_active.back = ST_MENU_ACTIVE_COLORS(ms).back;
-		if (Pdepth > 2)
-		{
-			c_active.hilight =
-				GetHilite(ST_MENU_ACTIVE_COLORS(ms).back);
-			c_active.shadow =
-				GetShadow(ST_MENU_ACTIVE_COLORS(ms).back);
-		}
-		else
-		{
-			c_active.hilight = GetColor(DEFAULT_HILIGHT_COLOR);
-			c_active.shadow = GetColor(DEFAULT_SHADOW_COLOR);
-		}
-	}
-	if (ST_HAS_GREYED_CSET(ms))
-	{
-		c_stipple.fore = greyed_cs->fg;
-		c_stipple.back = greyed_cs->fg;
-	}
-	else
-	{
-		c_stipple.fore = ST_MENU_STIPPLE_COLORS(ms).fore;
-		c_stipple.back = ST_MENU_STIPPLE_COLORS(ms).back;
-	}
-	if (ST_HAS_TITLE_CSET(ms))
-	{
-		c_title.fore = title_cs->fg;
-		c_title.back = title_cs->bg;
-		c_title.hilight = title_cs->hilite;
-		c_title.shadow = title_cs->shadow;
-	}
-	else
-	{
-		c_title.fore = c_inactive.fore;
-		c_title.back = c_inactive.back;
-		c_title.hilight = c_inactive.hilight;
-		c_title.shadow = c_inactive.shadow;
-	}
-	/* override highlighting colours if necessary */
-	if (!ST_DO_HILIGHT_FORE(ms))
-	{
-		c_active.fore = c_inactive.fore;
-	}
-	if (!ST_DO_HILIGHT_BACK(ms))
-	{
-		c_active.back = c_inactive.back;
-		c_active.hilight = c_inactive.hilight;
-		c_active.shadow = c_inactive.shadow;
-	}
-	if (!ST_DO_HILIGHT_TITLE_BACK(ms))
-	{
-		c_title.fore = c_inactive.fore;
-		c_title.back = c_inactive.back;
-		c_title.hilight = c_inactive.hilight;
-		c_title.shadow = c_inactive.shadow;
-	}
 	/* make GC's */
 	gcm = GCFunction|GCLineWidth|GCForeground|GCBackground;
 	if (ST_PSTDFONT(ms)->font != NULL)
@@ -721,25 +302,28 @@ void menustyle_update(MenuStyle *ms)
 	gcv.function = GXcopy;
 	gcv.line_width = 0;
 	/* update inactive menu gcs */
-	gcv.foreground = c_inactive.fore;
-	gcv.background = c_inactive.back;
+	gcv.foreground = menu_cs->fg;
+	gcv.background = menu_cs->bg;
 	change_or_make_gc(&FORE_GC(ST_MENU_INACTIVE_GCS(ms)), gcm, &gcv);
 	BACK_GC(ST_MENU_INACTIVE_GCS(ms)) = FORE_GC(ST_MENU_INACTIVE_GCS(ms));
-	gcv.foreground = c_inactive.hilight;
-	gcv.background = c_inactive.shadow;
+	gcv.foreground = menu_cs->hilite;
+	gcv.background = menu_cs->shadow;
 	change_or_make_gc(&HILIGHT_GC(ST_MENU_INACTIVE_GCS(ms)), gcm, &gcv);
-	gcv.foreground = c_inactive.shadow;
-	gcv.background = c_inactive.hilight;
+	gcv.foreground = menu_cs->shadow;
+	gcv.background = menu_cs->hilite;
 	change_or_make_gc(&SHADOW_GC(ST_MENU_INACTIVE_GCS(ms)), gcm, &gcv);
 	/* update active menu gcs */
-	gcv.foreground = c_active.fore;
-	gcv.background = c_active.back;
+	gcv.foreground = (ST_DO_HILIGHT_FORE(ms)) ? active_cs->fg
+						  : menu_cs->fg;
+	gcv.background = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->bg
+						  : menu_cs->bg;
 	change_or_make_gc(&FORE_GC(ST_MENU_ACTIVE_GCS(ms)), gcm, &gcv);
-	gcv.foreground = c_active.back;
-	gcv.background = c_active.fore;
+	gcv.foreground = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->bg
+						  : menu_cs->bg;
+	gcv.background = (ST_DO_HILIGHT_FORE(ms)) ? active_cs->fg
+						  : menu_cs->fg;
 
-	if (ST_HAS_ACTIVE_CSET(ms) && active_cs->pixmap &&
-	    active_cs->pixmap_type == PIXMAP_TILED)
+	if (active_cs->pixmap && active_cs->pixmap_type == PIXMAP_TILED)
 	{
 		gcv.tile = active_cs->pixmap;
 		gcv.fill_style = FillTiled;
@@ -753,12 +337,15 @@ void menustyle_update(MenuStyle *ms)
 				  gcm | GCFillStyle , &gcv);
 	}
 
-
-	gcv.foreground = c_active.hilight;
-	gcv.background = c_active.shadow;
+	gcv.foreground = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->hilite
+						  : menu_cs->hilite;
+	gcv.background = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->shadow
+						  : menu_cs->shadow;
 	change_or_make_gc(&HILIGHT_GC(ST_MENU_ACTIVE_GCS(ms)), gcm, &gcv);
-	gcv.foreground = c_active.shadow;
-	gcv.background = c_active.hilight;
+	gcv.foreground = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->shadow
+						  : menu_cs->shadow;
+	gcv.background = (ST_DO_HILIGHT_BACK(ms)) ? active_cs->hilite
+						  : menu_cs->hilite;
 	change_or_make_gc(&SHADOW_GC(ST_MENU_ACTIVE_GCS(ms)), gcm, &gcv);
 	/* update title gcs */
 	if (ST_PTITLEFONT(ms)->font != NULL && ST_PSTDFONT(ms)->font == NULL)
@@ -769,14 +356,17 @@ void menustyle_update(MenuStyle *ms)
 		}
 		gcv.font = ST_PTITLEFONT(ms)->font->fid;
 	}
-	gcv.foreground = c_title.fore;
-	gcv.background = c_title.back;
+	gcv.foreground = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->fg
+							: menu_cs->fg;
+	gcv.background = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->bg
+							: menu_cs->bg;
 	change_or_make_gc(&FORE_GC(ST_MENU_TITLE_GCS(ms)), gcm, &gcv);
-	gcv.foreground = c_title.back;
-	gcv.background = c_title.fore;
+	gcv.foreground = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->bg
+							: menu_cs->bg;
+	gcv.background = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->fg
+							: menu_cs->fg;
 
-	if (ST_HAS_TITLE_CSET(ms) && title_cs->pixmap &&
-	    title_cs->pixmap_type == PIXMAP_TILED)
+	if (title_cs->pixmap && title_cs->pixmap_type == PIXMAP_TILED)
 	{
 		gcv.tile = title_cs->pixmap;
 		gcv.fill_style = FillTiled;
@@ -790,11 +380,15 @@ void menustyle_update(MenuStyle *ms)
 				  gcm | GCFillStyle , &gcv);
 	}
 
-	gcv.foreground = c_title.hilight;
-	gcv.background = c_title.shadow;
+	gcv.foreground = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->hilite
+							: menu_cs->hilite;
+	gcv.background = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->shadow
+							: menu_cs->shadow;
 	change_or_make_gc(&HILIGHT_GC(ST_MENU_TITLE_GCS(ms)), gcm, &gcv);
-	gcv.foreground = c_title.shadow;
-	gcv.background = c_title.hilight;
+	gcv.foreground = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->shadow
+							: menu_cs->shadow;
+	gcv.background = (ST_DO_HILIGHT_TITLE_BACK(ms)) ? title_cs->hilite
+							: menu_cs->hilite;
 	change_or_make_gc(&SHADOW_GC(ST_MENU_TITLE_GCS(ms)), gcm, &gcv);
 	/* update stipple menu gcs */
 	SHADOW_GC(ST_MENU_STIPPLE_GCS(ms)) =
@@ -810,8 +404,8 @@ void menustyle_update(MenuStyle *ms)
 	}
 	else
 	{
-		gcv.foreground = c_stipple.fore;
-		gcv.background = c_stipple.back;
+		gcv.foreground = greyed_cs->fg;
+		gcv.background = greyed_cs->bg;
 		HILIGHT_GC(ST_MENU_STIPPLE_GCS(ms)) =
 			HILIGHT_GC(ST_MENU_INACTIVE_GCS(ms));
 	}
@@ -873,18 +467,17 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 	/* Parse the options. */
 	while (!is_initialised || (action && *action))
 	{
-	  	on = 1;
+		on = 1;
 		if (!is_initialised)
 		{
 			/* some default configuration goes here for the new
 			 * menu style */
-			ST_MENU_COLORS(tmpms).back =
-				GetColor(DEFAULT_BACK_COLOR);
-			ST_MENU_COLORS(tmpms).fore =
-				GetColor(DEFAULT_FORE_COLOR);
+			ST_CSET_MENU(tmpms) = 0;
+			ST_CSET_ACTIVE(tmpms) = 0;
+			ST_CSET_TITLE(tmpms) = 0;
+			ST_CSET_GREYED(tmpms) = 0;
 			ST_PSTDFONT(tmpms) = Scr.DefaultFont;
 			ST_USING_DEFAULT_FONT(tmpms) = True;
-			ST_FACE(tmpms).type = SimpleMenu;
 			ST_HAS_ACTIVE_FORE(tmpms) = 0;
 			ST_HAS_ACTIVE_BACK(tmpms) = 0;
 			ST_DO_POPUP_AS(tmpms) = MDP_POST_MENU;
@@ -895,6 +488,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			ST_SCROLL_OFF_PAGE(tmpms) = 1;
 			ST_DO_HILIGHT_TITLE_BACK(tmpms) = 0;
 			ST_USING_DEFAULT_TITLEFONT(tmpms) = True;
+			ST_TRANSLUCENT_PERCENT(tmpms) = 100;
 			has_gc_changed = True;
 			option = "fvwm";
 		}
@@ -976,12 +570,6 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			/* common settings */
 			ST_VERTICAL_MARGIN_TOP(tmpms) = 0;
 			ST_VERTICAL_MARGIN_BOTTOM(tmpms) = 0;
-			ST_CSET_MENU(tmpms) = 0;
-			ST_HAS_MENU_CSET(tmpms) = 0;
-			ST_CSET_ACTIVE(tmpms) = 0;
-			ST_HAS_ACTIVE_CSET(tmpms) = 0;
-			ST_CSET_GREYED(tmpms) = 0;
-			ST_HAS_GREYED_CSET(tmpms) = 0;
 			ST_BORDER_WIDTH(tmpms) = DEFAULT_MENU_BORDER_WIDTH;
 			ST_ACTIVE_AREA_PERCENT(tmpms) =
 				DEFAULT_MENU_POPUP_NOW_RATIO;
@@ -1003,8 +591,6 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			 * always close the menu and run the action.
 			 */
 			ST_HOTKEY_ACTIVATES_IMMEDIATE(tmpms) = 1;
-			menustyle_free_face(&ST_FACE(tmpms));
-			ST_FACE(tmpms).type = SimpleMenu;
 			if (ST_PSTDFONT(tmpms) && !ST_USING_DEFAULT_FONT(tmpms))
 			{
 				FlocaleUnloadFont(dpy, ST_PSTDFONT(tmpms));
@@ -1033,128 +619,33 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 3: /* Foreground */
-			fvwmlib_free_colors(
-				dpy, &ST_MENU_COLORS(tmpms).fore, 1, True);
-			if (arg1)
-			{
-				ST_MENU_COLORS(tmpms).fore = GetColor(arg1);
-			}
-			else
-			{
-				ST_MENU_COLORS(tmpms).fore =
-					GetColor(DEFAULT_FORE_COLOR);
-			}
-			has_gc_changed = True;
-			break;
-
-		case 4: /* Background */
-			fvwmlib_free_colors(
-				dpy, &ST_MENU_COLORS(tmpms).back, 1, True);
-			if (arg1)
-			{
-				ST_MENU_COLORS(tmpms).back = GetColor(arg1);
-			}
-			else
-			{
-				ST_MENU_COLORS(tmpms).back =
-					GetColor(DEFAULT_BACK_COLOR);
-			}
-			has_gc_changed = True;
-			break;
-
-		case 5: /* Greyed */
-			if (ST_HAS_STIPPLE_FORE(tmpms))
-			{
-				fvwmlib_free_colors(
-					dpy,
-					&ST_MENU_STIPPLE_COLORS(tmpms).fore, 1,
-					True);
-			}
-			if (arg1 == NULL)
-			{
-				ST_HAS_STIPPLE_FORE(tmpms) = 0;
-			}
-			else
-			{
-				ST_MENU_STIPPLE_COLORS(tmpms).fore =
-					GetColor(arg1);
-				ST_HAS_STIPPLE_FORE(tmpms) = 1;
-			}
-			has_gc_changed = True;
-			break;
-
-		case 7: /* HilightBackOff */
-			on ^= 1;
-			/* fall throw */
-		case 6: /* HilightBack */
-			if (ST_HAS_ACTIVE_BACK(tmpms))
-			{
-				fvwmlib_free_colors(
-					dpy,
-					&ST_MENU_ACTIVE_COLORS(tmpms).back, 1,
-					True);
-			}
-			if (arg1 == NULL || !on)
-			{
-				ST_HAS_ACTIVE_BACK(tmpms) = 0;
-			}
-			else
-			{
-				ST_MENU_ACTIVE_COLORS(tmpms).back =
-					GetColor(arg1);
-				ST_HAS_ACTIVE_BACK(tmpms) = 1;
-			}
+		case 3: /* HilightBack */
 			ST_DO_HILIGHT_BACK(tmpms) = on;
 			has_gc_changed = True;
 			break;
 
-		case 9: /* ActiveForeOff */
-			on ^= 1;
-			/* fall throw */
-		case 8: /* ActiveFore */
-			if (ST_HAS_ACTIVE_FORE(tmpms))
-			{
-				fvwmlib_free_colors(
-					dpy,
-					&ST_MENU_ACTIVE_COLORS(tmpms).fore, 1,
-					True);
-			}
-			if (arg1 == NULL || !on)
-			{
-				ST_HAS_ACTIVE_FORE(tmpms) = 0;
-			}
-			else
-			{
-				ST_MENU_ACTIVE_COLORS(tmpms).fore =
-					GetColor(arg1);
-				ST_HAS_ACTIVE_FORE(tmpms) = 1;
-			}
+		case 4: /* ActiveFore */
 			ST_DO_HILIGHT_FORE(tmpms) = on;
 			has_gc_changed = True;
 			break;
 
-		case 10: /* Hilight3DThick */
+		case 5: /* Hilight3DThick */
 			ST_RELIEF_THICKNESS(tmpms) = 2;
 			break;
 
-		case 11: /* Hilight3DThin */
+		case 6: /* Hilight3DThin */
 			ST_RELIEF_THICKNESS(tmpms) = 1;
 			break;
 
-		case 12: /* Hilight3DOff */
+		case 7: /* Hilight3DOff */
 			ST_RELIEF_THICKNESS(tmpms) = 0;
 			break;
 
-		case 13: /* Animation */
+		case 8: /* Animation */
 			ST_IS_ANIMATED(tmpms) = on;
 			break;
 
-		case 14: /* AnimationOff */
-			ST_IS_ANIMATED(tmpms) = !on;
-			break;
-
-		case 15: /* Font */
+		case 9: /* Font */
 			if (arg1 != NULL &&
 			    !(new_font = FlocaleLoadFont(dpy, arg1, "fvwm")))
 			{
@@ -1180,16 +671,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			has_gc_changed = True;
 			break;
 
-		case 16: /* MenuFace */
-			while (args && *args != '\0' &&
-			       isspace((unsigned char)*args))
-			{
-				args++;
-			}
-			menustyle_parse_face(args, &ST_FACE(tmpms), True);
-			break;
-
-		case 17: /* PopupDelay */
+		case 10: /* PopupDelay */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
@@ -1201,7 +683,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 18: /* PopupOffset */
+		case 11: /* PopupOffset */
 			if ((n = GetIntegerArguments(args, NULL, val, 2)) == 0)
 			{
 				fvwm_debug(__func__,
@@ -1222,51 +704,47 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 19: /* TitleWarp */
+		case 12: /* TitleWarp */
 			ST_DO_WARP_TO_TITLE(tmpms) = on;
 			break;
 
-		case 20: /* TitleWarpOff */
-			ST_DO_WARP_TO_TITLE(tmpms) = !on;
-			break;
-
-		case 21: /* TitleUnderlines0 */
+		case 13: /* TitleUnderlines0 */
 			ST_TITLE_UNDERLINES(tmpms) = 0;
 			break;
 
-		case 22: /* TitleUnderlines1 */
+		case 14: /* TitleUnderlines1 */
 			ST_TITLE_UNDERLINES(tmpms) = 1;
 			break;
 
-		case 23: /* TitleUnderlines2 */
+		case 15: /* TitleUnderlines2 */
 			ST_TITLE_UNDERLINES(tmpms) = 2;
 			break;
 
-		case 24: /* SeparatorsLong */
+		case 16: /* SeparatorsLong */
 			ST_HAS_LONG_SEPARATORS(tmpms) = on;
 			break;
 
-		case 25: /* SeparatorsShort */
+		case 17: /* SeparatorsShort */
 			ST_HAS_LONG_SEPARATORS(tmpms) = !on;
 			break;
 
-		case 26: /* TrianglesSolid */
+		case 18: /* TrianglesSolid */
 			ST_HAS_TRIANGLE_RELIEF(tmpms) = !on;
 			break;
 
-		case 27: /* TrianglesRelief */
+		case 19: /* TrianglesRelief */
 			ST_HAS_TRIANGLE_RELIEF(tmpms) = on;
 			break;
 
-		case 28: /* PopupImmediately */
+		case 20: /* PopupImmediately */
 			ST_DO_POPUP_IMMEDIATELY(tmpms) = on;
 			break;
 
-		case 29: /* PopupDelayed */
+		case 21: /* PopupDelayed */
 			ST_DO_POPUP_IMMEDIATELY(tmpms) = !on;
 			break;
 
-		case 30: /* DoubleClickTime */
+		case 22: /* DoubleClickTime */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
@@ -1279,7 +757,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 31: /* SidePic */
+		case 23: /* SidePic */
 			if (ST_SIDEPIC(tmpms))
 			{
 				PDestroyFvwmPicture(dpy, ST_SIDEPIC(tmpms));
@@ -1299,7 +777,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 32: /* SideColor */
+		case 24: /* SideColor */
 			if (ST_HAS_SIDE_COLOR(tmpms) == 1)
 			{
 				fvwmlib_free_colors(
@@ -1313,31 +791,31 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 33: /* PopupAsRootmenu */
+		case 25: /* PopupAsRootmenu */
 			ST_DO_POPUP_AS(tmpms) = MDP_ROOT_MENU;
 			break;
 
-		case 34: /* PopupAsSubmenu */
+		case 26: /* PopupAsSubmenu */
 			ST_DO_POPUP_AS(tmpms) = MDP_POST_MENU;
 			break;
 
-		case 35: /* RemoveSubmenus */
+		case 27: /* RemoveSubmenus */
 			ST_DO_UNMAP_SUBMENU_ON_POPDOWN(tmpms) = on;
 			break;
 
-		case 36: /* HoldSubmenus */
+		case 28: /* HoldSubmenus */
 			ST_DO_UNMAP_SUBMENU_ON_POPDOWN(tmpms) = !on;
 			break;
 
-		case 37: /* SubmenusRight */
+		case 29: /* SubmenusRight */
 			ST_USE_LEFT_SUBMENUS(tmpms) = !on;
 			break;
 
-		case 38: /* SubmenusLeft */
+		case 30: /* SubmenusLeft */
 			ST_USE_LEFT_SUBMENUS(tmpms) = on;
 			break;
 
-		case 39: /* BorderWidth */
+		case 31: /* BorderWidth */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0 || *val > MAX_MENU_BORDER_WIDTH)
 			{
@@ -1350,7 +828,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 40: /* Hilight3DThickness */
+		case 32: /* Hilight3DThickness */
 			if (GetIntegerArguments(args, NULL, val, 1) > 0)
 			{
 				if (*val < 0)
@@ -1368,7 +846,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 41: /* ItemFormat */
+		case 33: /* ItemFormat */
 			if (ST_ITEM_FORMAT(tmpms))
 			{
 				free(ST_ITEM_FORMAT(tmpms));
@@ -1380,15 +858,11 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 42: /* AutomaticHotkeys */
+		case 34: /* AutomaticHotkeys */
 			ST_USE_AUTOMATIC_HOTKEYS(tmpms) = on;
 			break;
 
-		case 43: /* AutomaticHotkeysOff */
-			ST_USE_AUTOMATIC_HOTKEYS(tmpms) = !on;
-			break;
-
-		case 44: /* VerticalItemSpacing */
+		case 35: /* VerticalItemSpacing */
 			parse_vertical_spacing_line(
 				args, &ST_ITEM_GAP_ABOVE(tmpms),
 				&ST_ITEM_GAP_BELOW(tmpms),
@@ -1396,61 +870,57 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 				DEFAULT_MENU_ITEM_TEXT_Y_OFFSET2);
 			break;
 
-		case 45: /* VerticalTitleSpacing */
+		case 36: /* VerticalTitleSpacing */
 			parse_vertical_spacing_line(
 				args, &ST_TITLE_GAP_ABOVE(tmpms),
 				&ST_TITLE_GAP_BELOW(tmpms),
 				DEFAULT_MENU_TITLE_TEXT_Y_OFFSET,
 				DEFAULT_MENU_TITLE_TEXT_Y_OFFSET2);
 			break;
-		case 46: /* MenuColorset */
+
+		case 37: /* MenuColorset */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
-				ST_HAS_MENU_CSET(tmpms) = 0;
 				ST_CSET_MENU(tmpms) = 0;
 			}
 			else
 			{
-				ST_HAS_MENU_CSET(tmpms) = 1;
 				ST_CSET_MENU(tmpms) = *val;
 				alloc_colorset(*val);
 			}
 			has_gc_changed = True;
 			break;
-		case 47: /* ActiveColorset */
+
+		case 38: /* ActiveColorset */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
-				ST_HAS_ACTIVE_CSET(tmpms) = 0;
 				ST_CSET_ACTIVE(tmpms) = 0;
 			}
 			else
 			{
-				ST_HAS_ACTIVE_CSET(tmpms) = 1;
 				ST_CSET_ACTIVE(tmpms) = *val;
 				alloc_colorset(*val);
 			}
 			has_gc_changed = True;
 			break;
 
-		case 48: /* GreyedColorset */
+		case 39: /* GreyedColorset */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
-				ST_HAS_GREYED_CSET(tmpms) = 0;
 				ST_CSET_GREYED(tmpms) = 0;
 			}
 			else
 			{
-				ST_HAS_GREYED_CSET(tmpms) = 1;
 				ST_CSET_GREYED(tmpms) = *val;
 				alloc_colorset(*val);
 			}
 			has_gc_changed = True;
 			break;
 
-		case 49: /* SelectOnRelease */
+		case 40: /* SelectOnRelease */
 			keycode = 0;
 			if (arg1)
 			{
@@ -1460,15 +930,15 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			ST_SELECT_ON_RELEASE_KEY(tmpms) = keycode;
 			break;
 
-		case 50: /* PopdownImmediately */
+		case 41: /* PopdownImmediately */
 			ST_DO_POPDOWN_IMMEDIATELY(tmpms) = 1;
 			break;
 
-		case 51: /* PopdownDelayed */
+		case 42: /* PopdownDelayed */
 			ST_DO_POPDOWN_IMMEDIATELY(tmpms) = 0;
 			break;
 
-		case 52: /* PopdownDelay */
+		case 43: /* PopdownDelay */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
@@ -1480,7 +950,7 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 53: /* PopupActiveArea */
+		case 44: /* PopupActiveArea */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val <= 50 || *val > 100)
 			{
@@ -1493,17 +963,17 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			break;
 
-		case 54: /* PopupIgnore */
+		case 45: /* PopupIgnore */
 			ST_DO_POPUP_AS(tmpms) = MDP_IGNORE;
 			break;
 
-		case 55: /* PopupClose */
+		case 46: /* PopupClose */
 			ST_DO_POPUP_AS(tmpms) = MDP_CLOSE;
 			break;
 
-		case 56: /* MouseWheel */
+		case 47: /* MouseWheel */
 			if (arg1)
-		        {
+			{
 				if (StrEquals(arg1, "ActivatesItem"))
 				{
 					ST_MOUSE_WHEEL(tmpms) = MMW_OFF;
@@ -1530,40 +1000,42 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 						   arg1);
 					ST_MOUSE_WHEEL(tmpms) = MMW_POINTER;
 				}
-		        }
-		        else
-		        {
-		        	ST_MOUSE_WHEEL(tmpms) =
+			}
+			else
+			{
+				ST_MOUSE_WHEEL(tmpms) =
 					(on) ? MMW_POINTER : MMW_OFF;
 			}
 			break;
-		case 57: /* ScrollOffPage */
-	        	ST_SCROLL_OFF_PAGE(tmpms) = on;
+
+		case 48: /* ScrollOffPage */
+			ST_SCROLL_OFF_PAGE(tmpms) = on;
 			break;
 
-		case 58: /* TrianglesUseFore */
+		case 49: /* TrianglesUseFore */
 			ST_TRIANGLES_USE_FORE(tmpms) = on;
 			break;
-		case 59: /* TitleColorset */
+
+		case 50: /* TitleColorset */
 			if (GetIntegerArguments(args, NULL, val, 1) == 0 ||
 			    *val < 0)
 			{
-				ST_HAS_TITLE_CSET(tmpms) = 0;
 				ST_CSET_TITLE(tmpms) = 0;
 			}
 			else
 			{
-				ST_HAS_TITLE_CSET(tmpms) = 1;
 				ST_CSET_TITLE(tmpms) = *val;
 				alloc_colorset(*val);
 			}
 			has_gc_changed = True;
 			break;
-		case 60: /* TitleHilightBack */
+
+		case 51: /* TitleHilightBack */
 			ST_DO_HILIGHT_TITLE_BACK(tmpms) = on;
 			has_gc_changed = True;
 			break;
-		case 61: /* TitleFont */
+
+		case 52: /* TitleFont */
 			if (arg1 != NULL &&
 			    !(new_font = FlocaleLoadFont(dpy, arg1, "fvwm")))
 			{
@@ -1590,16 +1062,30 @@ MenuStyle *menustyle_parse_style(F_CMD_ARGS)
 			}
 			has_gc_changed = True;
 			break;
-		case 62: /* VerticalMargins */
+
+		case 53: /* VerticalMargins */
 			parse_vertical_margins_line(
 				args, &ST_VERTICAL_MARGIN_TOP(tmpms),
 				&ST_VERTICAL_MARGIN_BOTTOM(tmpms),
 				0, 0);
 			break;
-		case 63: /* UniqueHotKeyActivatesImmediate */
+
+		case 54: /* UniqueHotKeyActivatesImmediate */
 			ST_HOTKEY_ACTIVATES_IMMEDIATE(tmpms) = on;
 			break;
 
+		case 55: /* Translucent */
+			if (!on ||
+			    GetIntegerArguments(args, NULL, val, 1) == 0 ||
+			    *val < 0 || *val > 100)
+			{
+				/* 100 percent means not translucent */
+				ST_TRANSLUCENT_PERCENT(tmpms) = 100;
+			} else {
+				ST_TRANSLUCENT_PERCENT(tmpms) = *val;
+			}
+			break;
+
 #if 0
 		case 99: /* PositionHints */
 			/* to be implemented */
@@ -1664,36 +1150,8 @@ void menustyle_copy(MenuStyle *origms, MenuStyle *destms)
 	/* Copy origms to destms, be aware of all pointers in the MenuStyle
 	   structure. Use  the same order as in menustyle_parse_style */
 
-	/* menu colors */
-	fvwmlib_copy_color(
-		dpy, &ST_MENU_COLORS(destms).fore,
-		&ST_MENU_COLORS(origms).fore, True, True);
-	fvwmlib_copy_color(
-		dpy, &ST_MENU_COLORS(destms).back,
-		&ST_MENU_COLORS(origms).back, True, True);
-	/* Greyed */
-	fvwmlib_copy_color(
-		dpy, &ST_MENU_STIPPLE_COLORS(destms).fore,
-		&ST_MENU_STIPPLE_COLORS(origms).fore,
-		ST_HAS_STIPPLE_FORE(destms), ST_HAS_STIPPLE_FORE(origms));
-	ST_MENU_STIPPLE_COLORS(destms).back =
-		ST_MENU_STIPPLE_COLORS(origms).back;
-	ST_HAS_STIPPLE_FORE(destms) = ST_HAS_STIPPLE_FORE(origms);
-
-	/* HilightBack */
-	fvwmlib_copy_color(
-		dpy, &ST_MENU_ACTIVE_COLORS(destms).back,
-		&ST_MENU_ACTIVE_COLORS(origms).back,
-		ST_HAS_ACTIVE_BACK(destms), ST_HAS_ACTIVE_BACK(origms));
-	ST_HAS_ACTIVE_BACK(destms) = ST_HAS_ACTIVE_BACK(origms);
+	/* HilightBack / ActiveFore */
 	ST_DO_HILIGHT_BACK(destms) = ST_DO_HILIGHT_BACK(origms);
-
-	/* ActiveFore */
-	fvwmlib_copy_color(
-		dpy, &ST_MENU_ACTIVE_COLORS(destms).fore,
-		&ST_MENU_ACTIVE_COLORS(origms).fore,
-		ST_HAS_ACTIVE_FORE(destms), ST_HAS_ACTIVE_FORE(origms));
-	ST_HAS_ACTIVE_FORE(destms) = ST_HAS_ACTIVE_FORE(origms);
 	ST_DO_HILIGHT_FORE(destms) = ST_DO_HILIGHT_FORE(origms);
 
 	/* Hilight3D */
@@ -1754,8 +1212,6 @@ void menustyle_copy(MenuStyle *origms, MenuStyle *destms)
 		ST_USING_DEFAULT_TITLEFONT(destms) = True;
 		ST_PTITLEFONT(destms) = Scr.DefaultFont;
 	}
-	/* MenuFace */
-	menustyle_copy_face(&ST_FACE(destms), &ST_FACE(origms));
 
 	/* PopupDelay */
 	ST_POPUP_DELAY(destms) = ST_POPUP_DELAY(origms);
@@ -1831,17 +1287,10 @@ void menustyle_copy(MenuStyle *origms, MenuStyle *destms)
 	ST_ITEM_GAP_BELOW(destms) = ST_ITEM_GAP_BELOW(origms);
 	ST_TITLE_GAP_ABOVE(destms) = ST_TITLE_GAP_ABOVE(origms);
 	ST_TITLE_GAP_BELOW(destms) = ST_TITLE_GAP_BELOW(origms);
-	/* MenuColorset */
-	ST_HAS_MENU_CSET(destms) = ST_HAS_MENU_CSET(origms);
+	/* MenuColorsets */
 	ST_CSET_MENU(destms) = ST_CSET_MENU(origms);
-	/* ActiveColorset */
-	ST_HAS_ACTIVE_CSET(destms) = ST_HAS_ACTIVE_CSET(origms);
 	ST_CSET_ACTIVE(destms) = ST_CSET_ACTIVE(origms);
-	/* MenuColorset */
-	ST_HAS_GREYED_CSET(destms) = ST_HAS_GREYED_CSET(origms);
 	ST_CSET_GREYED(destms) = ST_CSET_GREYED(origms);
-	/* TitleColorset */
-	ST_HAS_TITLE_CSET(destms) = ST_HAS_TITLE_CSET(origms);
 	ST_CSET_TITLE(destms) = ST_CSET_TITLE(origms);
 	/* SelectOnRelease */
 	ST_SELECT_ON_RELEASE_KEY(destms) = ST_SELECT_ON_RELEASE_KEY(origms);
@@ -1905,9 +1354,7 @@ void CMD_CopyMenuStyle(F_CMD_ARGS)
 	if (!destms)
 	{
 		/* create destms menu style */
-		/* TA:  FIXME!  xasprintf() */
-		buffer = fxmalloc(strlen(destname) + 3);
-		sprintf(buffer,"\"%s\"",destname);
+		xasprintf(&buffer, "\"%s\"", destname);
 		action = buffer;
 		destms = menustyle_parse_style(F_PASS_ARGS);
 		free(buffer);
@@ -1949,27 +1396,6 @@ void CMD_CopyMenuStyle(F_CMD_ARGS)
 
 void CMD_MenuStyle(F_CMD_ARGS)
 {
-	char *option;
-	char *poption;
-
-	GetNextSimpleOption(SkipNTokens(action, 1), &option);
-	poption = option;
-	while (poption && poption[0] == '!')
-	{
-		poption++;
-	}
-	if (option == NULL || menustyle_get_styleopt_index(poption) != -1)
-	{
-		(void)menustyle_parse_style(F_PASS_ARGS);
-	}
-	else
-	{
-		(void)menustyle_parse_old_style(F_PASS_ARGS);
-	}
-	if (option)
-	{
-		free(option);
-	}
-
+	(void)menustyle_parse_style(F_PASS_ARGS);
 	return;
 }
