@@ -28,13 +28,13 @@
 #include "libs/Strings.h"
 #include "fvwm.h"
 #include "externs.h"
+#include "cmdparser.h"
 #include "cursor.h"
 #include "functions.h"
 #include "events.h"
 #include "misc.h"
 #include "screen.h"
 
-#define MAX_READ_DEPTH 40
 static char *curr_read_file = NULL;
 static char *curr_read_dir = NULL;
 static int curr_read_depth = 0;
@@ -112,10 +112,12 @@ const char *get_current_read_dir(void)
  * Read and execute each line from stream.
  */
 void run_command_stream(
-	cond_rc_t *cond_rc, FILE *f, const exec_context_t *exc)
+	cond_rc_t *cond_rc, FILE *f, const exec_context_t *exc,
+	cmdparser_context_t *pc)
 {
 	char *tline;
 	char line[1024];
+	int count;
 
 	/* Set close-on-exec flag */
 	fcntl(fileno(f), F_SETFD, 1);
@@ -125,7 +127,7 @@ void run_command_stream(
 	handle_all_expose();
 
 	tline = fgets(line, (sizeof line) - 1, f);
-	while (tline)
+	for (count = 0; tline && count < MAX_READ_ITEMS; count++)
 	{
 		int l;
 		while (tline && (l = strlen(line)) < sizeof(line) && l >= 2 &&
@@ -143,9 +145,15 @@ void run_command_stream(
 		{
 			tline[l - 1] = '\0';
 		}
-		execute_function(cond_rc, exc, tline, 0);
+		execute_function(cond_rc, exc, tline, pc, 0);
 		tline = fgets(line, (sizeof line) - 1, f);
 	}
+	if (tline)
+	{
+		fvwm_debug(
+			__func__, "Too many lines in inpup (> %d).",
+			MAX_READ_ITEMS);
+	}
 
 	return;
 }
@@ -192,7 +200,7 @@ static int parse_filename(
  * Returns 0 if file not found
  **/
 int run_command_file(
-	char *filename, const exec_context_t *exc)
+	char *filename, const exec_context_t *exc, cmdparser_context_t *pc)
 {
 	char *full_filename;
 	FILE *f = NULL;
@@ -251,7 +259,7 @@ int run_command_file(
 		fclose(f);
 		return 0;
 	}
-	run_command_stream(NULL, f, exc);
+	run_command_stream(NULL, f, exc, pc);
 	fclose(f);
 	pop_read_file();
 
@@ -317,7 +325,7 @@ void CMD_Read(F_CMD_ARGS)
 		return;
 	}
 	cursor_control(True);
-	if (!run_command_file(filename, exc))
+	if (!run_command_file(filename, exc, pc))
 	{
 		if (!read_quietly)
 		{
@@ -384,7 +392,7 @@ void CMD_PipeRead(F_CMD_ARGS)
 	}
 	free(command);
 
-	run_command_stream(cond_rc,f, exc);
+	run_command_stream(cond_rc, f, exc, pc);
 	pclose(f);
 	cursor_control(False);
 
