@@ -10,8 +10,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /* ---------------------------- included header files ---------------------- */
@@ -27,6 +26,7 @@
 #include "libs/gravity.h"
 #include "libs/Grab.h"
 #include "libs/Parse.h"
+#include "libs/FEvent.h"
 #include "libs/defaults.h"
 #include "fvwm.h"
 #include "externs.h"
@@ -44,7 +44,6 @@
 #include "virtual.h"
 #include "geometry.h"
 #include "icons.h"
-#include "gnome.h"
 #include "ewmh.h"
 #include "frame.h"
 
@@ -98,7 +97,7 @@ static int collect_transients_recursive(
 /* ---------------------------- local functions ---------------------------- */
 
 #define DEBUG_STACK_RING 1
-#ifdef DEBUG_STACK_RING
+#if DEBUG_STACK_RING
 /* debugging function */
 static void dump_stack_ring(void)
 {
@@ -109,13 +108,14 @@ static void dump_stack_ring(void)
 		return;
 	}
 	XBell(dpy, 0);
-	fprintf(stderr,"dumping stack ring:\n");
+	fvwm_debug(__func__, "dumping stack ring:\n");
 	for (
 		t1 = Scr.FvwmRoot.stack_next; t1 != &Scr.FvwmRoot;
 		t1 = t1->stack_next)
 	{
-		fprintf(stderr,"    l=%d fw=%p f=0x%08x '%s'\n", t1->layer,
-			t1, (int)FW_W_FRAME(t1), t1->name.name);
+		fvwm_debug(__func__, "    l=%d fw=%p f=0x%08x '%s'\n",
+			   t1->layer,
+			   t1, (int)FW_W_FRAME(t1), t1->name.name);
 	}
 
 	return;
@@ -149,12 +149,11 @@ void verify_stack_ring_consistency(void)
 	{
 		if (t1->layer > last_layer)
 		{
-			fprintf(
-				stderr,
-				"vsrc: stack ring is corrupt! '%s' (layer %d)"
-				" is above '%s' (layer %d/%d)\n",
-				t1->name.name, t1->layer, t2->name.name,
-				t2->layer, last_layer);
+			fvwm_debug(__func__,
+				   "vsrc: stack ring is corrupt! '%s'"
+				   " (layer %d) is above '%s' (layer %d/%d)\n",
+				   t1->name.name, t1->layer, t2->name.name,
+				   t2->layer, last_layer);
 			dump_stack_ring();
 			return;
 		}
@@ -172,11 +171,10 @@ void verify_stack_ring_consistency(void)
 	}
 	if (t1 != &Scr.FvwmRoot || t1->stack_prev != t2)
 	{
-		fprintf(
-			stderr,
-			"vsrc: stack ring is corrupt -"
-			" fvwm will probably crash! %p -> %p but %p <- %p",
-			t2, t1, t1->stack_prev, t1);
+		fvwm_debug(__func__,
+			   "vsrc: stack ring is corrupt -"
+			   " fvwm will probably crash! %p -> %p but %p <- %p",
+			   t2, t1, t1->stack_prev, t1);
 		dump_stack_ring();
 		return;
 	}
@@ -201,20 +199,19 @@ void verify_stack_ring_consistency(void)
 		}
 		if (i == nchildren)
 		{
-			fprintf(
-				stderr,"vsrc: window already died:"
-				" fw=%p w=0x%08x '%s'\n",
-				t1, (int)FW_W_FRAME(t1), t1->name.name);
+			fvwm_debug(__func__, "vsrc: window already died:"
+				   " fw=%p w=0x%08x '%s'\n",
+				   t1, (int)FW_W_FRAME(t1), t1->name.name);
 		}
 		else if (i >= last_index)
 		{
-			fprintf(
-				stderr, "vsrc: window is at wrong position"
-				" in stack ring: fw=%p f=0x%08x '%s'\n",
-				t1, (int)FW_W_FRAME(t1),
-				t1->name.name);
+			fvwm_debug(__func__,
+				   "vsrc: window is at wrong position"
+				   " in stack ring: fw=%p f=0x%08x '%s'\n",
+				   t1, (int)FW_W_FRAME(t1),
+				   t1->name.name);
 			dump_stack_ring();
-			fprintf(stderr,"dumping X stacking order:\n");
+			fvwm_debug(__func__, "dumping X stacking order:\n");
 			for (i = nchildren; i-- > 0; )
 			{
 				for (
@@ -225,9 +222,9 @@ void verify_stack_ring_consistency(void)
 					/* only dump frame windows */
 					if (FW_W_FRAME(t1) == children[i])
 					{
-						fprintf(
-							stderr, "  f=0x%08x\n",
-							(int)children[i]);
+						fvwm_debug(__func__,
+							   "  f=0x%08x\n",
+							   (int)children[i]);
 						break;
 					}
 				}
@@ -243,6 +240,8 @@ void verify_stack_ring_consistency(void)
 
 	return;
 }
+#else
+#define verify_stack_ring_consistency() do { } while (0)
 #endif
 
 /* Add a whole ring of windows. The list_head itself will not be added. */
@@ -316,7 +315,7 @@ static void raise_over_unmanaged(FvwmWindow *t)
 
 		if (count > 0)
 		{
-			wins = (Window*) safemalloc (count * sizeof (Window));
+			wins = fxmalloc(count * sizeof (Window));
 			for (
 				i = 0, t2 = Scr.FvwmRoot.stack_next;
 				t2 != &Scr.FvwmRoot; t2 = t2->stack_next)
@@ -529,14 +528,13 @@ static void __restack_window_list(
 		}
 	}
 	/* restack the windows between r and s */
-	wins = (Window *)safemalloc((count + 3) * sizeof(Window));
+	wins = fxmalloc((count + 3) * sizeof(Window));
 	for (t = r->stack_next, i = 0; t != s; t = t->stack_next)
 	{
 		if (i > count)
 		{
-			fvwm_msg(
-				ERR, "__restack_window_list",
-				"more transients than expected");
+			fvwm_debug(__func__,
+				   "more transients than expected");
 			break;
 		}
 		wins[i++] = FW_W_FRAME(t);
@@ -579,7 +577,7 @@ static void __restack_window_list(
 		XRestackWindows(dpy, wins, count);
 	}
 	free(wins);
-	EWMH_SetClientListStacking();
+	EWMH_SetClientListStacking(monitor_get_current());
 	if (do_broadcast_all)
 	{
 		/* send out M_RESTACK for all windows, to make sure we don't
@@ -747,7 +745,7 @@ static Bool is_transient_subtree_straight(
 	}
 	/* find out on which windows to operate */
 	/* iteration are done reverse (bottom up, since that's the way the
-	 * transients wil be stacked if all is well */
+	 * transients will be stacked if all is well */
 	if (layer >= 0)
 	{
 		/* only work on the given layer */
@@ -790,7 +788,7 @@ static Bool is_transient_subtree_straight(
 			s->scratch.p = NULL;
 		}
 	}
-	/* Indicate that no cleening is needed */
+	/* Indicate that no cleaning is needed */
 	Scr.FvwmRoot.scratch.i = 1;
 	/* now loop over the windows and mark the ones we need to move */
 	SET_IN_TRANSIENT_SUBTREE(t, 1);
@@ -969,7 +967,7 @@ static Bool __restack_window(
 		 * raised/lowered too */
 		raise_or_lower_window(t, mode, True, False, is_client_request);
 		/* make sure the stacking order is correct - may be the
-		 * sledge-hammer method, but the recursion ist too hard to
+		 * sledge-hammer method, but the recursion is too hard to
 		 * understand. */
 		ResyncXStackingOrder();
 
@@ -1281,7 +1279,7 @@ static void ResyncXStackingOrder(void)
 	}
 	if (count > 0)
 	{
-		wins = (Window *)safemalloc(3 * count * sizeof (Window));
+		wins = fxmalloc(3 * count * sizeof (Window));
 		for (
 			i = 0, t = Scr.FvwmRoot.stack_next; count--;
 			t = t->stack_next)
@@ -1364,8 +1362,7 @@ static void BroadcastRestack(FvwmWindow *s1, FvwmWindow *s2)
 	{
 		n = min(num, max_wins_per_packet) - 1;
 		length = FvwmPacketHeaderSize + 3 * (n + 1);
-		body = (unsigned long *)safemalloc(
-			length * sizeof(unsigned long));
+		body = fxmalloc(length * sizeof(unsigned long));
 		bp = body;
 		*(bp++) = START_FLAG;
 		*(bp++) = M_RESTACK;
@@ -1387,9 +1384,10 @@ static void BroadcastRestack(FvwmWindow *s1, FvwmWindow *s2)
 		}
 		free(body);
 	}
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
 
 	return;
 }
@@ -1459,8 +1457,9 @@ static Bool is_above_unmanaged(FvwmWindow *fw, Window *umtop)
 	unsigned int num;
 	Window OR_Above = None;
 	XWindowAttributes wa;
+	struct monitor	*m = fw->m;
 
-	if (fw->Desk != Scr.CurrentDesk)
+	if (fw->Desk != m->virtual_scr.CurrentDesk)
 	{
 		return True;
 	}
@@ -1513,6 +1512,7 @@ static Bool is_on_top_of_layer_ignore_rom(FvwmWindow *fw)
 {
 	FvwmWindow *t;
 	Bool ontop = True;
+	struct monitor *m = fw->m;
 
 	if (IS_SCHEDULED_FOR_DESTROY(fw))
 	{
@@ -1525,6 +1525,9 @@ static Bool is_on_top_of_layer_ignore_rom(FvwmWindow *fw)
 	}
 	for (t = fw->stack_prev; t != &Scr.FvwmRoot; t = t->stack_prev)
 	{
+		if (t->m != m)
+			continue;
+
 		if (t->layer > fw->layer)
 		{
 			break;
@@ -1551,15 +1554,18 @@ static Bool is_on_top_of_layer_ignore_rom(FvwmWindow *fw)
 	return ontop;
 }
 
+#define EXPERIMENTAL_ROU_HANDLING 0
+#define ROUDEBUG 0
 static Bool __is_on_top_of_layer(FvwmWindow *fw, Bool client_entered)
 {
 	Window	junk;
 	Bool  ontop	= False;
-	if (Scr.bo.do_raise_over_unmanaged)
+	if (!Scr.bo.do_raise_over_unmanaged)
+	{
+		return is_on_top_of_layer_ignore_rom(fw);
+	}
+	if (EXPERIMENTAL_ROU_HANDLING)
 	{
-
-#define EXPERIMENTAL_ROU_HANDLING
-#ifdef EXPERIMENTAL_ROU_HANDLING
 		/*
 		  RBW - 2002/08/15 -
 		  RaiseOverUnmanaged adds some overhead. The only way to let our
@@ -1580,23 +1586,28 @@ static Bool __is_on_top_of_layer(FvwmWindow *fw, Bool client_entered)
 			if (client_entered)
 				/* FIXME! - perhaps we should only do if MFCR */
 			{
-#ifdef ROUDEBUG
-				printf("RBW-iotol  - %8.8lx is on top,"
-				       " checking server tree.  ***\n",
-				       FW_W_CLIENT(fw));
-#endif
+				if (ROUDEBUG)
+				{
+					printf("RBW-iotol  - %8.8lx is on top,"
+					       " checking server tree.  ***\n",
+					       FW_W_CLIENT(fw));
+				}
 				ontop = is_above_unmanaged(fw, &junk);
-#ifdef ROUDEBUG
-				printf("	 returning %d\n", (int) ontop);
-#endif
+				if (ROUDEBUG)
+				{
+					printf(
+						"	 returning %d\n",
+						(int) ontop);
+				}
 			}
 			else
 			{
-#ifdef ROUDEBUG
-				printf("RBW-iotol  - %8.8lx is on top,"
-				       " *** NOT checking server tree.\n",
-				       FW_W_CLIENT(fw));
-#endif
+				if (ROUDEBUG)
+				{
+					printf("RBW-iotol  - %8.8lx is on top,"
+					       " *** NOT checking server"
+					       " tree.\n", FW_W_CLIENT(fw));
+				}
 				ontop = True;
 			}
 			return ontop;
@@ -1605,13 +1616,10 @@ static Bool __is_on_top_of_layer(FvwmWindow *fw, Bool client_entered)
 		{
 			return False;
 		}
-#else
-		return False;	/*  Old pre-2002/08/22 handling.  */
-#endif
 	}
 	else
 	{
-		return is_on_top_of_layer_ignore_rom(fw);
+		return False;	/*  Old pre-2002/08/22 handling.  */
 	}
 }
 
@@ -1626,7 +1634,7 @@ void remove_window_from_stack_ring(FvwmWindow *t)
 	}
 	t->stack_prev->stack_next = t->stack_next;
 	t->stack_next->stack_prev = t->stack_prev;
-	/* not really necessary, but gives a little more saftey */
+	/* not really necessary, but gives a little more safety */
 	t->stack_prev = NULL;
 	t->stack_next = NULL;
 
@@ -1643,12 +1651,11 @@ void add_window_to_stack_ring_after(FvwmWindow *t, FvwmWindow *add_after_win)
 	if (t == add_after_win || t == add_after_win->stack_next)
 	{
 		/* tried to add the window before or after itself */
-		fvwm_msg(
-			ERR, "add_window_to_stack_ring_after",
-			"BUG: tried to add window '%s' %s itself in stack"
-			" ring\n",
-			t->name.name, (t == add_after_win) ?
-			"after" : "before");
+		fvwm_debug(__func__,
+			   "BUG: tried to add window '%s' %s itself in stack"
+			   " ring\n",
+			   t->name.name, (t == add_after_win) ?
+			   "after" : "before");
 		return;
 	}
 	t->stack_next = add_after_win->stack_next;
@@ -1716,9 +1723,11 @@ void RaiseWindow(FvwmWindow *t, Bool is_client_request)
 		(unsigned long)t);
 	raise_or_lower_window(t, SM_RAISE, True, False, is_client_request);
 	focus_grab_buttons_on_layer(t->layer);
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
+
 	return;
 }
 
@@ -1729,9 +1738,11 @@ void LowerWindow(FvwmWindow *t, Bool is_client_request)
 		(unsigned long)t);
 	raise_or_lower_window(t, SM_LOWER, True, False, is_client_request);
 	focus_grab_buttons_on_layer(t->layer);
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
+
 	return;
 }
 
@@ -1739,9 +1750,11 @@ void RestackWindow(FvwmWindow *t, Bool is_client_request)
 {
 	raise_or_lower_window(t, SM_RESTACK, True, False, is_client_request);
 	focus_grab_buttons_on_layer(t->layer);
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
+
 	return;
 }
 
@@ -1798,9 +1811,11 @@ Bool HandleUnusualStackmodes(
 		break;
 	}
 	/*  DBUG("HandleUnusualStackmodes", "\t---> %d\n", do_restack);*/
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
+
 	return do_restack;
 }
 
@@ -2009,7 +2024,6 @@ void new_layer(FvwmWindow *fw, int layer)
 		border_draw_decorations(
 			s, PART_TITLEBAR, (Scr.Hilite == fw), True, CLEAR_NONE,
 			NULL, NULL);
-		GNOME_SetLayer(fw);
 		EWMH_SetWMState(fw, False);
 	}
 	/* move the windows without modifying their stacking order */
@@ -2124,9 +2138,10 @@ void CMD_Layer(F_CMD_ARGS)
 		layer = 0;
 	}
 	new_layer(fw, layer);
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
 
 	return;
 }
@@ -2144,9 +2159,8 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 		i = atoi (bot);
 		if (i < 0)
 		{
-			fvwm_msg(
-				ERR, "DefaultLayers",
-				"Layer must be non-negative." );
+			fvwm_debug(__func__,
+				   "Layer must be non-negative." );
 		}
 		else
 		{
@@ -2159,9 +2173,8 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 		i = atoi (def);
 		if (i < 0)
 		{
-			fvwm_msg(
-				ERR, "DefaultLayers",
-				"Layer must be non-negative." );
+			fvwm_debug(__func__,
+				   "Layer must be non-negative." );
 		}
 		else
 		{
@@ -2174,18 +2187,18 @@ void CMD_DefaultLayers(F_CMD_ARGS)
 		i = atoi (top);
 		if (i < 0)
 		{
-			fvwm_msg(
-				ERR, "DefaultLayers",
-				"Layer must be non-negative." );
+			fvwm_debug(__func__,
+				   "Layer must be non-negative." );
 		}
 		else
 		{
 			Scr.TopLayer = i;
 		}
 	}
-#ifdef DEBUG_STACK_RING
-	verify_stack_ring_consistency();
-#endif
+	if (DEBUG_STACK_RING)
+	{
+		verify_stack_ring_consistency();
+	}
 
 	return;
 }
