@@ -18,10 +18,6 @@
 	((sf)->do_start_shaded)
 #define SHAS_BORDER_WIDTH(sf) \
 	((sf)->has_border_width)
-#define SHAS_COLOR_BACK(sf) \
-	((sf)->has_color_back)
-#define SHAS_COLOR_FORE(sf) \
-	((sf)->has_color_fore)
 #define SHAS_HANDLE_WIDTH(sf) \
 	((sf)->has_handle_width)
 #define SHAS_ICON(sf) \
@@ -426,22 +422,6 @@
 	((s).decor_name)
 #define SSET_DECOR_NAME(s,x) \
 	((s).decor_name = (x))
-#define SGET_FORE_COLOR_NAME(s) \
-	((s).fore_color_name)
-#define SSET_FORE_COLOR_NAME(s,x) \
-	((s).fore_color_name = (x))
-#define SGET_BACK_COLOR_NAME(s) \
-	((s).back_color_name)
-#define SSET_BACK_COLOR_NAME(s,x) \
-	((s).back_color_name = (x))
-#define SGET_FORE_COLOR_NAME_HI(s) \
-	((s).fore_color_name_hi)
-#define SSET_FORE_COLOR_NAME_HI(s,x) \
-	((s).fore_color_name_hi = (x))
-#define SGET_BACK_COLOR_NAME_HI(s) \
-	((s).back_color_name_hi)
-#define SSET_BACK_COLOR_NAME_HI(s,x) \
-	((s).back_color_name_hi = (x))
 #define SGET_ICON_FONT(s) \
 	((s).icon_font)
 #define SSET_ICON_FONT(s,x) \
@@ -454,20 +434,20 @@
 	((s).colorset)
 #define SSET_COLORSET(s,x) \
 	((s).colorset = (x))
-#define SSET_BORDER_COLORSET(s,x) \
-	((s).border_colorset = (x))
-#define SGET_BORDER_COLORSET(s) \
-	((s).border_colorset)
 #define SGET_COLORSET_HI(s) \
 	((s).colorset_hi)
 #define SSET_COLORSET_HI(s,x) \
 	((s).colorset_hi = (x))
-#define SGET_BORDER_COLORSET_HI(s) \
-	((s).border_colorset_hi)
-#define SSET_BORDER_COLORSET_HI(s,x) \
-	((s).border_colorset_hi = (x))
+#define SSET_BORDER_COLORSET(s,p,x) \
+	((s).border_colorset[(p)] = (x))
+#define SGET_BORDER_COLORSET(s, p) \
+	((s).border_colorset[(p)])
+#define SGET_BORDER_COLORSET_HI(s,p) \
+	((s).border_colorset_hi[(p)])
+#define SSET_BORDER_COLORSET_HI(s,p,x) \
+	((s).border_colorset_hi[(p)] = (x))
 #define SSET_ICON_TITLE_COLORSET(s,x) \
-	((s).icon_title_colorset = (x))
+        ((s).icon_title_colorset = (x))
 #define SGET_ICON_TITLE_COLORSET(s) \
 	((s).icon_title_colorset)
 #define SSET_ICON_TITLE_COLORSET_HI(s,x) \
