@@ -1,9 +1,9 @@
-#ifndef FCURSOR_H
-#define FCURSOR_H
+#ifndef FVWMLIB_FCURSOR_H
+#define FVWMLIB_FCURSOR_H
+
+#include "fvwm_x11.h"
 
 #ifdef HAVE_XCURSOR
-#	include <X11/Xcursor/Xcursor.h>
-
 	typedef XcursorImage			FcursorImage;
 	typedef XcursorImages			FcursorImages;
 	typedef XcursorPixel			FcursorPixel;
@@ -39,4 +39,4 @@
 #	define FcursorImagesLoadCursor(a,b) 0
 #endif
 
-#endif /* FCURSOR_H */
+#endif /* FVWMLIB_FCURSOR_H */
