@@ -11,8 +11,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 /* FlocaleRotateDrawString is strongly inspired by some part of xvertext
  * taken from wmx */
@@ -115,9 +114,10 @@ void FlocaleParseShadow(char *str, int *shadow_size, int *shadow_offset,
 	    *shadow_size < 0)
 	{
 		*shadow_size = 0;
-		fprintf(stderr,"[%s][FlocaleParseShadow]: WARNING -- bad "
-			"shadow size in font name:\n\t'%s'\n",
-			(module)? module: "fvwm", fontname);
+		fvwm_debug(__func__,
+		           "[%s][FlocaleParseShadow]: WARNING -- bad "
+		           "shadow size in font name:\n\t'%s'\n",
+		           (module)? module: "fvwm", fontname);
 		return;
 	}
 	if (*shadow_size == 0)
@@ -131,9 +131,10 @@ void FlocaleParseShadow(char *str, int *shadow_size, int *shadow_offset,
 		if (*shadow_offset < 0)
 		{
 			*shadow_offset = 0;
-			fprintf(stderr,"[%s][FlocaleParseShadow]: WARNING -- "
-				"bad shadow offset in font name:\n\t'%s'\n",
-				(module)? module: "fvwmlibs", fontname);
+			fvwm_debug(__func__,
+				   "[%s][FlocaleParseShadow]: WARNING -- "
+				   "bad shadow offset in font name:\n\t'%s'\n",
+				   (module)? module: "fvwmlibs", fontname);
 		}
 		PeekToken(dir_str, &dir_str);
 	}
@@ -142,10 +143,11 @@ void FlocaleParseShadow(char *str, int *shadow_size, int *shadow_offset,
 		dir = gravity_parse_multi_dir_argument(dir_str, &dir_str);
 		if (dir == MULTI_DIR_NONE)
 		{
-			fprintf(stderr,"[%s][FlocaleParseShadow]: WARNING -- "
-				"bad shadow direction in font description:\n"
-				"\t%s\n",
-				(module)? module: "fvwmlibs", fontname);
+			fvwm_debug(__func__,
+				   "[%s][FlocaleParseShadow]: WARNING -- "
+				   "bad shadow direction in font description:\n"
+				   "\t%s\n",
+				   (module)? module: "fvwmlibs", fontname);
 			PeekToken(dir_str, &dir_str); /* skip it */
 		}
 		else
@@ -291,7 +293,7 @@ XChar2b *FlocaleUtf8ToUnicodeStr2b(char *str, int len, int *nl)
 	XChar2b *str2b = NULL;
 	int i = 0, j = 0, t;
 
-	str2b = (XChar2b *)safemalloc((len+1)*sizeof(XChar2b));
+	str2b = fxmalloc((len + 1) * sizeof(XChar2b));
 	while (i < len && str[i] != 0)
 	{
 		if ((str[i] & 0x80) == 0)
@@ -354,7 +356,7 @@ XChar2b *FlocaleStringToString2b(
 	{
 		euc = False;
 	}
-	str2b = (XChar2b *)safemalloc((len+1)*sizeof(XChar2b));
+	str2b = fxmalloc((len + 1) * sizeof(XChar2b));
 	if (euc)
 	{
 		while (i < len && str[i] != 0)
@@ -447,7 +449,14 @@ char *FlocaleEncodeString(
 	}
 
 	str1 = str;
-	if (FiconvSupport)
+
+        if (FftSupport && flf->fftf.fftfont[0])
+	{
+		if (comb_chars) *comb_chars = NULL;
+		comb_chars = NULL;
+	}
+
+	if (FiconvSupport && comb_chars)
 	{
 		char *tmp_str;
 
@@ -510,8 +519,7 @@ char *FlocaleEncodeString(
 		/* initialise array with composing characters (empty) */
 		if(comb_chars != NULL && *comb_chars == NULL)
 		{
-			*comb_chars = (superimpose_char_t *)
-				safemalloc(sizeof(superimpose_char_t));
+			*comb_chars = fxmalloc(sizeof *comb_chars);
 			(*comb_chars)[0].position = -1;
  			(*comb_chars)[0].c.byte1 = 0;
  			(*comb_chars)[0].c.byte2 = 0;
@@ -522,7 +530,7 @@ char *FlocaleEncodeString(
 		*/
 		if(l_to_v != NULL && *l_to_v == NULL)
 		{
-			*l_to_v = (int*)safemalloc((len + 1) * sizeof(int));
+			*l_to_v = fxmalloc((len + 1) * sizeof(int));
 			for(i = 0 ; i < len ; i++)
 				(*l_to_v)[i] = i;
 			(*l_to_v)[len] = -1;
@@ -746,8 +754,8 @@ void FlocaleRotateDrawString(
 				/* if conversion failed, combinational char
 				   is not representable in current charset */
 				/* just replace with empty string */
-				buf2 = (char *)safemalloc(sizeof(char));
-				buf2[0] = 0;
+				buf2 = fxmalloc(sizeof(char));
+				*buf2 = '\0';
 			}
 			tmp_fws.e_str = buf2;
 			tmp_fws.str2b = NULL;
@@ -762,8 +770,8 @@ void FlocaleRotateDrawString(
 			{
 				if (FLC_ENCODING_TYPE_IS_UTF_8(flf->fc))
 				{
-					tmp_fws.str2b = (XChar2b *)
-					       safemalloc(2 * sizeof(XChar2b));
+					tmp_fws.str2b =
+						fxmalloc(2 * sizeof(XChar2b));
 					tmp_fws.str2b[0] = comb_chars[i].c;
 					tmp_fws.str2b[1].byte1 = 0;
 					tmp_fws.str2b[1].byte2 = 0;
@@ -798,7 +806,7 @@ void FlocaleRotateDrawString(
 	}
 
 	/* reserve memory for the first XImage */
-	normal_data = (unsigned char *)safemalloc(normal_len * normal_h);
+	normal_data = fxmalloc(normal_len * normal_h);
 
 	/* create depth 1 XImage */
 	if ((image = XCreateImage(
@@ -831,7 +839,7 @@ void FlocaleRotateDrawString(
 	rotated_len = (rotated_w - 1) / 8 + 1;
 
 	/* reserve memory for the rotated image */
-	rotated_data = (unsigned char *)safecalloc(rotated_h * rotated_len, 1);
+	rotated_data = fxcalloc(rotated_h * rotated_len, 1);
 
 	/* create the rotated X image */
 	if ((rotated_image = XCreateImage(
@@ -1097,14 +1105,13 @@ FlocaleFont *FlocaleGetFftFont(
 		}
 		return NULL;
 	}
-	flf = (FlocaleFont *)safemalloc(sizeof(FlocaleFont));
-	memset(flf, '\0', sizeof(FlocaleFont));
+	flf = fxcalloc(1, sizeof(FlocaleFont));
 	flf->count = 1;
 	flf->fftf = *fftf;
 	FlocaleCharsetSetFlocaleCharset(dpy, flf, hints, encoding, module);
 	FftGetFontHeights(
 		&flf->fftf, &flf->height, &flf->ascent, &flf->descent);
-	FftGetFontWidths(flf, &flf->max_char_width);
+
 	free(fftf);
 	if (fn != NULL && fn != fft_fallback_font)
 	{
@@ -1120,7 +1127,7 @@ FlocaleFont *FlocaleGetFontSet(
 {
 	static int mc_errors = 0;
 	FlocaleFont *flf = NULL;
-	XFontSet fontset = NULL;
+	XFontSet fontset;
 	char **ml;
 	int mc,i;
 	char *ds;
@@ -1141,6 +1148,11 @@ FlocaleFont *FlocaleGetFontSet(
 		}
 		return NULL;
 	}
+	/* dv (26-Nov-2021):  libx11-1.7.2 has a memory leak here.  If a
+	 * non-default locale is used in LC_CTYPE, XCreateFontSet() +
+	 * XFreeFontSet() leaks some memory.  See
+	 * https://gitlab.freedesktop.org/xorg/lib/libx11/-/issues/143
+	 */
 	if (!(fontset = XCreateFontSet(dpy, fn_fixed, &ml, &mc, &ds)))
 	{
 		if (fn_fixed && fn_fixed != fn)
@@ -1151,6 +1163,10 @@ FlocaleFont *FlocaleGetFontSet(
 		{
 			free(fn);
 		}
+		if (ml != NULL)
+		{
+			XFreeStringList(ml);
+		}
 		return NULL;
 	}
 
@@ -1159,30 +1175,29 @@ FlocaleFont *FlocaleGetFontSet(
 		if (mc_errors <= FLOCALE_NUMBER_MISS_CSET_ERR_MSG)
 		{
 			mc_errors++;
-			fprintf(stderr,
-				"[%s][FlocaleGetFontSet]: (%s)"
-				" Missing font charsets:\n",
-				(module)? module: "fvwmlibs", fontname);
+			fvwm_debug(__func__,
+				   "[%s][FlocaleGetFontSet]: (%s)"
+				   " Missing font charsets:\n",
+				   (module)? module: "fvwmlibs", fontname);
 			for (i = 0; i < mc; i++)
 			{
-				fprintf(stderr, "%s", ml[i]);
+				fvwm_debug(__func__, "%s", ml[i]);
 				if (i < mc - 1)
-					fprintf(stderr, ", ");
+					fvwm_debug(__func__, ", ");
 			}
-			fprintf(stderr, "\n");
+			fvwm_debug(__func__, "\n");
 			if (mc_errors == FLOCALE_NUMBER_MISS_CSET_ERR_MSG)
 			{
-				fprintf(stderr,
-					"[%s][FlocaleGetFontSet]: No more"
-					" missing charset reportings\n",
-					(module)? module: "fvwmlibs");
+				fvwm_debug(__func__,
+					   "[%s][FlocaleGetFontSet]: No more"
+					   " missing charset reportings\n",
+					   (module)? module: "fvwmlibs");
 			}
 		}
 		XFreeStringList(ml);
 	}
 
-	flf = (FlocaleFont *)safemalloc(sizeof(FlocaleFont));
-	memset(flf, '\0', sizeof(FlocaleFont));
+	flf = fxcalloc(1, sizeof(FlocaleFont));
 	flf->count = 1;
 	flf->fontset = fontset;
 	FlocaleCharsetSetFlocaleCharset(dpy, flf, hints, encoding, module);
@@ -1191,7 +1206,7 @@ FlocaleFont *FlocaleGetFontSet(
 	flf->ascent = - fset_extents->max_ink_extent.y;
 	flf->descent = fset_extents->max_ink_extent.height +
 		fset_extents->max_ink_extent.y;
-	flf->max_char_width = fset_extents->max_ink_extent.width;
+
 	if (fn_fixed && fn_fixed != fn)
 	{
 		free(fn_fixed);
@@ -1246,17 +1261,15 @@ FlocaleFont *FlocaleGetFont(
 		return NULL;
 	}
 
-	flf = (FlocaleFont *)safemalloc(sizeof(FlocaleFont));
-	memset(flf, '\0', sizeof(FlocaleFont));
+	flf = fxcalloc(1, sizeof(FlocaleFont));
 	flf->count = 1;
 	flf->fontset = None;
-	flf->fftf.fftfont = NULL;
+	memset(&flf->fftf, 0, sizeof(FftFontType));
 	flf->font = font;
 	FlocaleCharsetSetFlocaleCharset(dpy, flf, hints, encoding, module);
 	flf->height = font->max_bounds.ascent + font->max_bounds.descent;
 	flf->ascent = font->max_bounds.ascent;
 	flf->descent = font->max_bounds.descent;
-	flf->max_char_width = font->max_bounds.width;
 	if (flf->font->max_byte1 > 0)
 		flf->flags.is_mb = True;
 	if (fn != NULL && fn != fallback_font)
@@ -1278,8 +1291,11 @@ FlocaleFont *FlocaleGetFontOrFontSet(
 {
 	FlocaleFont *flf = NULL;
 
-	if (fontname && strlen(fontname) > 3 &&
-	    strncasecmp("xft:", fontname, 4) == 0)
+	if (fontname == NULL)
+	{
+		return NULL;
+	}
+	if (strlen(fontname) > 3 && strncasecmp("xft:", fontname, 4) == 0)
 	{
 		if (FftSupport)
 		{
@@ -1292,31 +1308,31 @@ FlocaleFont *FlocaleGetFontOrFontSet(
 		}
 		return flf;
 	}
-	if (flf == NULL && Flocale != NULL && fontname)
+	if (flf == NULL && Flocale != NULL)
 	{
 		flf = FlocaleGetFontSet(dpy, fontname, encoding, module);
 	}
-	if (flf == NULL && fontname)
+	if (flf == NULL)
 	{
 		flf = FlocaleGetFont(dpy, fontname, encoding, module);
 	}
-	if (flf && fontname)
+	if (flf == NULL)
 	{
-		if (StrEquals(fullname, mb_fallback_font))
-		{
-			flf->name = mb_fallback_font;
-		}
-		else if (StrEquals(fullname, fallback_font))
-		{
-			flf->name = fallback_font;
-		}
-		else
-		{
-			CopyString(&flf->name, fullname);
-		}
-		return flf;
+		return NULL;
 	}
-	return NULL;
+	if (StrEquals(fullname, mb_fallback_font))
+	{
+		flf->name = mb_fallback_font;
+	}
+	else if (StrEquals(fullname, fallback_font))
+	{
+		flf->name = fallback_font;
+	}
+	else
+	{
+		CopyString(&flf->name, fullname);
+	}
+	return flf;
 }
 
 /*
@@ -1329,18 +1345,20 @@ void FlocaleSetlocaleForX(
 {
 	if ((Flocale = setlocale(category, locale)) == NULL)
 	{
-		fprintf(stderr,
-			"[%s][%s]: ERROR -- Cannot set locale. Please check"
-			" your $LC_CTYPE or $LANG.\n",
-			(module == NULL)? "" : module, "FlocaleSetlocaleForX");
+		fvwm_debug(__func__,
+			   "[%s][%s]: ERROR -- Cannot set locale. Please check"
+			   " your $LC_CTYPE or $LANG.\n",
+			   (module == NULL)? "" : module,
+			   "FlocaleSetlocaleForX");
 		return;
 	}
 	if (!XSupportsLocale())
 	{
-		fprintf(stderr,
-			"[%s][%s]: WARNING -- X does not support locale %s\n",
-			(module == NULL)? "": module, "FlocaleSetlocaleForX",
-			Flocale);
+		fvwm_debug(__func__,
+			   "[%s][%s]: WARNING -- X does not support locale %s\n",
+			   (module == NULL)? "": module,
+			   "FlocaleSetlocaleForX",
+			   Flocale);
 		Flocale = NULL;
 	}
 }
@@ -1363,13 +1381,13 @@ void FlocaleInit(
 	if (modifiers != NULL &&
 	    (Fmodifiers = XSetLocaleModifiers(modifiers)) == NULL)
 	{
-		fprintf(stderr,
-			"[%s][%s]: WARNING -- Cannot set locale modifiers\n",
-			(module == NULL)? "": module, "FlocaleInit");
+		fvwm_debug(__func__,
+			   "[%s][%s]: WARNING -- Cannot set locale modifiers\n",
+			   (module == NULL)? "": module, "FlocaleInit");
 	}
 #if FLOCALE_DEBUG_SETLOCALE
-	fprintf(stderr,"[%s][FlocaleInit] locale: %s, modifier: %s\n",
-		module, Flocale, Fmodifiers);
+	fvwm_debug(__func__, "[%s][FlocaleInit] locale: %s, modifier: %s\n",
+		   module, Flocale, Fmodifiers);
 #endif
 }
 
@@ -1493,10 +1511,10 @@ FlocaleFont *FlocaleLoadFont(Display *dpy, char *fontname, char *module)
 		/* loading failed, try default font */
 		if (!ask_default)
 		{
-			fprintf(stderr,"[%s][FlocaleLoadFont]: "
-				"WARNING -- can't load font '%s',"
-				" trying default:\n",
-				(module)? module: "fvwmlibs", fontname);
+			fvwm_debug(__func__, "[%s][FlocaleLoadFont]: "
+				   "WARNING -- can't load font '%s',"
+				   " trying default:\n",
+				   (module)? module: "fvwmlibs", fontname);
 		}
 		else
 		{
@@ -1506,8 +1524,8 @@ FlocaleFont *FlocaleLoadFont(Display *dpy, char *fontname, char *module)
 		{
 			if (!ask_default)
 			{
-				fprintf(stderr, "\t%s\n",
-					mb_fallback_font);
+				fvwm_debug(__func__, "\t%s\n",
+					   mb_fallback_font);
 			}
 			if ((flf = FlocaleGetFontSet(
 				     dpy, mb_fallback_font, NULL,
@@ -1520,8 +1538,8 @@ FlocaleFont *FlocaleLoadFont(Display *dpy, char *fontname, char *module)
 		{
 			if (!ask_default)
 			{
-				fprintf(stderr,"\t%s\n",
-					fallback_font);
+				fvwm_debug(__func__, "\t%s\n",
+					   fallback_font);
 			}
 			if ((flf =
 			     FlocaleGetFont(
@@ -1532,21 +1550,21 @@ FlocaleFont *FlocaleLoadFont(Display *dpy, char *fontname, char *module)
 			}
 			else if (!ask_default)
 			{
-				fprintf(stderr,
-					"[%s][FlocaleLoadFont]:"
-					" ERROR -- can't load font.\n",
-					(module)? module: "fvwmlibs");
+				fvwm_debug(__func__,
+					   "[%s][FlocaleLoadFont]:"
+					   " ERROR -- can't load font.\n",
+					   (module)? module: "fvwmlibs");
 			}
 			else
 			{
-				fprintf(stderr,
-					"[%s][FlocaleLoadFont]: ERROR"
-					" -- can't load default font:\n",
-					(module)? module: "fvwmlibs");
-				fprintf(stderr, "\t%s\n",
-					mb_fallback_font);
-				fprintf(stderr, "\t%s\n",
-					fallback_font);
+				fvwm_debug(__func__,
+					   "[%s][FlocaleLoadFont]: ERROR"
+					   " -- can't load default font:\n",
+					   (module)? module: "fvwmlibs");
+				fvwm_debug(__func__, "\t%s\n",
+					   mb_fallback_font);
+				fvwm_debug(__func__, "\t%s\n",
+					   fallback_font);
 			}
 		}
 	}
@@ -1561,24 +1579,22 @@ FlocaleFont *FlocaleLoadFont(Display *dpy, char *fontname, char *module)
 			flf->descent += FLF_SHADOW_DESCENT(flf);
 			flf->ascent += FLF_SHADOW_ASCENT(flf);
 			flf->height += FLF_SHADOW_HEIGHT(flf);
-			flf->max_char_width += FLF_SHADOW_WIDTH(flf);
 		}
 		if (flf->fc == FlocaleCharsetGetUnknownCharset())
 		{
-			fprintf(stderr,"[%s][FlocaleLoadFont]: "
-				"WARNING -- Unknown charset for font\n\t'%s'\n",
-				(module)? module: "fvwmlibs", flf->name);
+			fvwm_debug(__func__, "[%s][FlocaleLoadFont]: "
+				   "WARNING -- Unknown charset for font\n\t'%s'\n",
+				   (module)? module: "fvwmlibs", flf->name);
 			flf->fc = FlocaleCharsetGetDefaultCharset(dpy, module);
 		}
 		else if (flf->str_fc == FlocaleCharsetGetUnknownCharset() &&
 			 (encoding != NULL ||
-			  (FftSupport && flf->fftf.fftfont != NULL &&
-			   flf->fftf.str_encoding != NULL)))
+			  (FftSupport && flf->fftf.fftfont[0] != NULL)))
 		{
-			fprintf(stderr,"[%s][FlocaleLoadFont]: "
-				"WARNING -- Unknown string encoding for font\n"
-				"\t'%s'\n",
-				(module)? module: "fvwmlibs", flf->name);
+			fvwm_debug(__func__, "[%s][FlocaleLoadFont]: "
+				   "WARNING -- Unknown string encoding for font\n"
+				   "\t'%s'\n",
+				   (module)? module: "fvwmlibs", flf->name);
 		}
 		if (flf->str_fc == FlocaleCharsetGetUnknownCharset())
 		{
@@ -1617,15 +1633,9 @@ void FlocaleUnloadFont(Display *dpy, FlocaleFont *flf)
 	{
 		free(flf->name);
 	}
-	if (FftSupport && flf->fftf.fftfont != NULL)
+	if (FftSupport && flf->fftf.fftfont[0] != NULL)
 	{
-		FftFontClose(dpy, flf->fftf.fftfont);
-		if (flf->fftf.fftfont_rotated_90 != NULL)
-			FftFontClose(dpy, flf->fftf.fftfont_rotated_90);
-		if (flf->fftf.fftfont_rotated_180 != NULL)
-			FftFontClose(dpy, flf->fftf.fftfont_rotated_180);
-		if (flf->fftf.fftfont_rotated_270 != NULL)
-			FftFontClose(dpy, flf->fftf.fftfont_rotated_270);
+		FftCloseFont(dpy, &flf->fftf);
 	}
 	if (flf->fontset != NULL)
 	{
@@ -1865,7 +1875,7 @@ void FlocaleDrawString(
 		   but there for clarity,
 		   ending at 0 is what's expected in a correct
 		   string */
-		pixel_pos = (int *)safemalloc(
+		pixel_pos = fxmalloc(
 			(char_len != 0 ? char_len : 1) * sizeof(int));
 
 		/* if there is 0 bytes in the encoded string, there might
@@ -1925,14 +1935,14 @@ void FlocaleDrawString(
 	}
 
 	if (fws->flags.text_rotation != ROTATION_0 &&
-	    flf->fftf.fftfont == NULL)
+	    flf->fftf.fftfont[0] == NULL)
 	{
 	        /* pass in information to perform superimposition */
 		FlocaleRotateDrawString(
 			dpy, flf, fws, fg, fgsh, has_fg_pixels, len,
 			comb_chars, pixel_pos);
 	}
-	else if (FftSupport && flf->fftf.fftfont != NULL)
+	else if (FftSupport && flf->fftf.fftfont[0] != NULL)
 	{
 		FftDrawString(
 			dpy, flf, fws, fg, fgsh, has_fg_pixels, len, flags);
@@ -1992,12 +2002,12 @@ void FlocaleDrawString(
 				/* if conversion failed, combinational char
 				   is not representable in current charset */
 				/* just replace with empty string */
-				buf2 = (char *)safemalloc(sizeof(char));
-				buf2[0] = 0;
+				buf2 = fxmalloc(sizeof(char));
+				*buf2 = '\0';
 			}
 			tmp_fws.e_str = buf2;
 			tmp_fws.str2b = NULL;
-			if(FftSupport && flf->fftf.fftfont != NULL)
+			if(FftSupport && flf->fftf.fftfont[0] != NULL)
 			{
 			        tmp_fws.x = fws->x + offset;
 				FftDrawString(
@@ -2038,8 +2048,8 @@ void FlocaleDrawString(
 			{
 				if (FLC_ENCODING_TYPE_IS_UTF_8(flf->fc))
 				{
-					tmp_fws.str2b = (XChar2b *)
-					       safemalloc(2 * sizeof(XChar2b));
+					tmp_fws.str2b = fxmalloc(
+							2 * sizeof(XChar2b));
 					tmp_fws.str2b[0] = comb_chars[i].c;
 					tmp_fws.str2b[1].byte1 = 0;
 					tmp_fws.str2b[1].byte2 = 0;
@@ -2106,7 +2116,6 @@ void FlocaleDrawUnderline(
 	Display *dpy, FlocaleFont *flf, FlocaleWinString *fws, int offset)
 {
 	int off1, off2, y, x_s, x_e;
-	superimpose_char_t *comb_chars = NULL;
 	int *l_to_v = NULL;
 	Bool do_free = True;
 	int len = strlen(fws->str);
@@ -2120,10 +2129,8 @@ void FlocaleDrawUnderline(
 	}
 
 	/* need to encode the string first to get BIDI and combining chars */
-	FlocaleEncodeWinString(dpy, flf, fws, &do_free, &len, &comb_chars,
+	FlocaleEncodeWinString(dpy, flf, fws, &do_free, &len, NULL,
 			       &l_to_v);
-	/* we don't need this, only interested in char mapping */
-	free(comb_chars);
 
 	/* now calculate char offset (in bytes) in visual string corresponding
 	   to coffset */
@@ -2213,9 +2220,9 @@ int FlocaleTextWidth(FlocaleFont *flf, char *str, int sl)
 		}
 		return FlocaleTextWidth(flf, " ", 1);
 	}
-	else if (FftSupport && flf->fftf.fftfont != NULL)
-		     {
-		result = FftTextWidth(flf, tmp_str, new_l);
+	else if (FftSupport && flf->fftf.fftfont[0] != NULL)
+	{
+		result = FftTextWidth(Pdpy, flf, tmp_str, new_l);
 	}
 	else if (flf->fontset != None)
 	{
@@ -2298,8 +2305,7 @@ int FlocaleGetMinOffset(
 
 void FlocaleAllocateWinString(FlocaleWinString **pfws)
 {
-	*pfws = (FlocaleWinString *)safemalloc(sizeof(FlocaleWinString));
-	memset(*pfws, '\0', sizeof(FlocaleWinString));
+	*pfws = fxcalloc(1, sizeof(FlocaleWinString));
 }
 
 /*
@@ -2358,7 +2364,14 @@ void FlocaleFreeNameProperty(FlocaleNameString *ptext)
 		XFreeStringList(ptext->name_list);
 		ptext->name_list = NULL;
 	}
-	else if (ptext->name != NULL)
+	else if (ptext->name != NULL
+                 /* Sorry, this is pretty ugly.
+                    in fvwm/events.c we have:
+                    FlocaleNameString new_name = { NoName, NULL };
+                    NoName is a global extern I don't want to add to
+                    to this libary module.
+                    So, this check comes close enough: */
+                 && strcmp("Untitled",ptext->name) != 0)
 	{
 		XFree(ptext->name);
 	}
@@ -2416,22 +2429,23 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 
 	fflush(stderr);
 	fflush(stdout);
-	fprintf(stderr,"fvwm info on locale:\n");
-	fprintf(stderr,"  locale: %s, Modifier: %s\n",
-		(Flocale)? Flocale:"", (Fmodifiers)? Fmodifiers:"");
+	fvwm_debug(__func__, "fvwm info on locale:\n");
+	fvwm_debug(__func__, "  locale: %s, Modifier: %s\n",
+		   (Flocale)? Flocale:"", (Fmodifiers)? Fmodifiers:"");
 	cs = FlocaleCharsetGetDefaultCharset(dpy, NULL);
-	fprintf(stderr,"  Default Charset:  X: %s, Iconv: %s, Bidi: %s\n",
-		cs->x,
-		(cs->iconv_index >= 0)?
-		cs->locale[cs->iconv_index]:"Not defined",
-		(cs->bidi)? "Yes":"No");
+	fvwm_debug(__func__,
+		   "  Default Charset:  X: %s, Iconv: %s, Bidi: %s\n",
+		   cs->x,
+		   (cs->iconv_index >= 0)?
+		   cs->locale[cs->iconv_index]:"Not defined",
+		   (cs->bidi)? "Yes":"No");
 	FlocaleCharsetPrintXOMInfo();
 	while (flf)
 	{
 		count++;
 		flf = flf->next;
 	}
-	fprintf(stderr,"  Number of loaded font: %i\n", count);
+	fvwm_debug(__func__, "  Number of loaded font: %i\n", count);
 	if (verbose)
 	{
 		count = 0;
@@ -2439,75 +2453,44 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 		while(flf)
 		{
 			cs = flf->fc;
-			fprintf(stderr,"  * Font number %i\n", count);
-			fprintf(stderr,"    fvwm info:\n");
-			fprintf(stderr,"      Name: %s\n",
-				(flf->name)?  flf->name:"");
-			fprintf(stderr,"      Cache count: %i\n", flf->count);
-			fprintf(stderr,"      Type: ");
+			fvwm_debug(__func__, "  * Font number %i\n", count);
+			fvwm_debug(__func__, "    fvwm info:\n");
+			fvwm_debug(__func__, "      Name: %s\n",
+				   (flf->name)?  flf->name:"");
+			fvwm_debug(__func__, "      Cache count: %i\n",
+				   flf->count);
+			fvwm_debug(__func__, "      Type: ");
 			if (flf->font)
 			{
-				fprintf(stderr,"FontStruct\n");
+				fvwm_debug(__func__, "FontStruct\n");
 			}
 			else if (flf->fontset)
 			{
-				fprintf(stderr,"FontSet\n");
+				fvwm_debug(__func__, "FontSet\n");
 			}
 			else
 			{
-				fprintf(stderr,"XftFont\n");
+				fvwm_debug(__func__, "XftFont\n");
 			}
-			fprintf(stderr, "      Charset:  X: %s, Iconv: %s, "
-				"Bidi: %s\n",
-				cs->x,
-				(cs->iconv_index >= 0)?
-				cs->locale[cs->iconv_index]:"Not defined",
-				(cs->bidi)? "Yes":"No");
-			fprintf(stderr,"      height: %i, ascent: %i, "
-				"descent: %i\n", flf->height, flf->ascent,
-				flf->descent);
-			fprintf(stderr,"      shadow size: %i, "
-				"shadow offset: %i, shadow direction:%i\n",
-				flf->shadow_size, flf->shadow_offset,
-				flf->flags.shadow_dir);
+			fvwm_debug(__func__,
+				   "      Charset:  X: %s, Iconv: %s, "
+				   "Bidi: %s\n",
+				   cs->x,
+				   (cs->iconv_index >= 0)?
+				   cs->locale[cs->iconv_index]:"Not defined",
+				   (cs->bidi)? "Yes":"No");
+			fvwm_debug(__func__, "      height: %i, ascent: %i, "
+				   "descent: %i\n", flf->height, flf->ascent,
+				   flf->descent);
+			fvwm_debug(__func__, "      shadow size: %i, "
+				   "shadow offset: %i, shadow direction:%i\n",
+				   flf->shadow_size, flf->shadow_offset,
+				   flf->flags.shadow_dir);
 			if (verbose >= 2)
 			{
-				if (flf->fftf.fftfont != NULL)
+				if (flf->fftf.fftfont[0] != NULL)
 				{
-					FftFontType *fftf;
-
-					fftf = &flf->fftf;
-					fprintf(stderr, "    Xft info:\n"
-						"      - Vertical font:");
-					FftPrintPatternInfo(
-						fftf->fftfont, False);
-					fprintf(stderr, "      "
-						"- Rotated font 90:");
-					if (fftf->fftfont_rotated_90)
-						FftPrintPatternInfo(
-							fftf->
-							fftfont_rotated_90,
-							True);
-					else
-						fprintf(stderr, " None\n");
-					fprintf(stderr, "      "
-						"- Rotated font 270:");
-					if (fftf->fftfont_rotated_270)
-						FftPrintPatternInfo(
-							fftf->
-							fftfont_rotated_270,
-							True);
-					else
-						fprintf(stderr, " None\n");
-					fprintf(stderr, "      "
-						"- Rotated font 180:");
-					if (fftf->fftfont_rotated_180)
-						FftPrintPatternInfo(
-							fftf->
-							fftfont_rotated_180,
-							True);
-					else
-						fprintf(stderr, " None\n");
+					FftPrintPatternInfo(&flf->fftf);
 				}
 				else if (flf->font != NULL)
 				{
@@ -2516,9 +2499,9 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 					full_name =
 						FlocaleGetFullNameOfFontStruct(
 							dpy, flf->font);
-					fprintf(stderr, "    X info:\n"
-						"      %s\n",
-						(full_name)? full_name:"?");
+					fvwm_debug(__func__, "    X info:\n"
+						   "      %s\n",
+						   (full_name)? full_name:"?");
 					if (full_name != NULL)
 					{
 						XFree(full_name);
@@ -2530,16 +2513,16 @@ void FlocalePrintLocaleInfo(Display *dpy, int verbose)
 					XFontStruct **font_struct_list;
 					char **font_name_list;
 
-					fprintf(stderr, "    X info:\n");
+					fvwm_debug(__func__, "    X info:\n");
 					n = XFontsOfFontSet(
 						flf->fontset,
 						&font_struct_list,
 						&font_name_list);
 					for(i = 0; i < n; i++)
 					{
-						fprintf(stderr,
-							"      %s\n",
-							font_name_list[i]);
+						fvwm_debug(__func__,
+							   "      %s\n",
+							   font_name_list[i]);
 					}
 				}
 			}
