@@ -13,8 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see: <http://www.gnu.org/licenses/>
  */
 
 /*
@@ -172,11 +171,14 @@ Bool PImageLoadSvg(FIMAGE_CMD_ARGS)
 
 	if (!USE_SVG)
 	{
+		fvwm_debug(__func__,
+				"[PImageLoadSvg]: Tried to load SVG file "
+				"when FVWM has not been compiled with SVG support.\n");
 		return False;
 	}
 
 	/* Separate rendering options from path */
-	render_opts = path = allocated_path = safestrdup(path);
+	render_opts = path = allocated_path = fxstrdup(path);
 	if (*path == ':' && (path = strchr(path + 1, ':')))
 	{
 		*path = 0;
@@ -317,8 +319,7 @@ Bool PImageLoadSvg(FIMAGE_CMD_ARGS)
 		angle += 90;
 	}
 
-	data = (CARD32 *)safemalloc(w * h * sizeof(CARD32));
-	memset(data, 0, w * h * sizeof(CARD32));
+	data = fxcalloc(1, w * h * sizeof(CARD32));
 	surface = Fcairo_image_surface_create_for_data((unsigned char *)data,
 		FCAIRO_FORMAT_ARGB32, w, h, w * sizeof(CARD32));
 	if (Fcairo_surface_status(surface) != FCAIRO_STATUS_SUCCESS)
@@ -410,13 +411,22 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 		/* suppress compiler warning */
 		bit_depth = 0;
 
+		fvwm_debug(__func__,
+				"[PImageLoadPng]: Tried to load PNG file "
+				"when FVWM has not been compiled with PNG support.\n");
+
 		return False;
 	}
 	if (!(f = fopen(path, "rb")))
 	{
 		return False;
 	}
-	fread(buf, 1, FPNG_BYTES_TO_CHECK, f);
+	{
+		int n;
+
+		n = fread(buf, 1, FPNG_BYTES_TO_CHECK, f);
+		(void)n;
+	}
 	if (!Fpng_check_sig(buf, FPNG_BYTES_TO_CHECK))
 	{
 		fclose(f);
@@ -460,7 +470,7 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 	}
 
 	/* TA:  XXX:  (2011-02-14) -- Happy Valentines Day.
-	 * 
+	 *
 	 * png_get_color_type() defined in libpng 1.5 now hides a data member
 	 * to a struct:
 	 *
@@ -508,8 +518,8 @@ Bool PImageLoadPng(FIMAGE_CMD_ARGS)
 		Fpng_set_expand(Fpng_ptr);
 	}
 
-	data = (CARD32 *)safemalloc(w * h * sizeof(CARD32));
-	lines = (unsigned char **) safemalloc(h * sizeof(unsigned char *));
+	data = fxmalloc(w * h * sizeof(CARD32));
+	lines = fxmalloc(h * sizeof(unsigned char *));
 
 	if (hasg)
 	{
@@ -560,6 +570,9 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 
 	if (!XpmSupport)
 	{
+		fvwm_debug(__func__,
+				"[PImageLoadXpm]: Tried to load XPM file "
+				"when FVWM has not been compiled with XPm Support.\n");
 		return False;
 	}
 	memset(&xpm_im, 0, sizeof(FxpmImage));
@@ -592,7 +605,7 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 		FxpmFreeXpmImage(&xpm_im);
 		return False;
 	}
-	colors = (CARD32 *)safemalloc(xpm_im.ncolors * sizeof(CARD32));
+	colors = fxmalloc(xpm_im.ncolors * sizeof(CARD32));
 	for (i=0; i < xpm_im.ncolors; i++)
 	{
 		xpm_color = &xpm_im.colorTable[i];
@@ -626,7 +639,7 @@ Bool PImageLoadXpm(FIMAGE_CMD_ARGS)
 	}
 	*width = w = xpm_im.width;
 	*height = h = xpm_im.height;
-	data = (CARD32 *)safemalloc(w * h * sizeof(CARD32));
+	data = fxmalloc(w * h * sizeof(CARD32));
 	for (i=0; i < w * h; i++)
 	{
 		data[i] = colors[xpm_im.data[i]];
@@ -886,8 +899,7 @@ FvwmPicture *PImageLoadFvwmPictureFromFile(
 		return NULL;
 	}
 
-	p = (FvwmPicture*)safemalloc(sizeof(FvwmPicture));
-	memset(p, 0, sizeof(FvwmPicture));
+	p = fxcalloc(1, sizeof(FvwmPicture));
 	p->count = 1;
 	p->name = path;
 	p->fpa_mask = fpa.mask;
