@@ -44,9 +44,7 @@
  */
 /* The first option of the default menu style must be fvwm/win/mwm/....
  * fvwm may crash if not. */
-#define DEFAULT_MENU_STYLE \
-        "MenuStyle * fvwm, Foreground black, Background grey, " \
-        "Greyed slategrey, MenuColorset, ActiveColorset, GreyedColorset"
+#define DEFAULT_MENU_STYLE "MenuStyle * fvwm"
 #define DEFAULT_CLICKTIME                150 /* ms */
 #define DEFAULT_POPUP_DELAY               15 /* ms*10 */
 #define DEFAULT_POPDOWN_DELAY             15 /* ms*10 */
@@ -102,10 +100,6 @@
 #define DEFAULT_MENU_GRADIENT_PIXMAP_THICKNESS 4
 
 /*** colours ***/
-#define DEFAULT_FORE_COLOR                "black"
-#define DEFAULT_BACK_COLOR                "gray"
-#define DEFAULT_HILIGHT_COLOR             "white"
-#define DEFAULT_SHADOW_COLOR              "black"
 #define DEFAULT_CURSOR_FORE_COLOR         "black"
 #define DEFAULT_CURSOR_BACK_COLOR         "white"
 
