@@ -122,7 +122,6 @@ Window icon_win;	       /* icon window */
 
 static int MyVx, MyVy;		/* copy of Scr.Vx/y for drag logic */
 
-static void adjust_for_sizehints(int, int);
 static rectangle CalcGeom(PagerWindow *, bool);
 static rectangle set_vp_size_and_loc(void);
 static void fvwmrec_to_pager(rectangle *, bool);
@@ -160,8 +159,8 @@ static void do_scroll(int sx, int sy, Bool do_send_message,
 	    ( psx != 0 || psy != 0 ))
 	{
 		if (monitor_to_track != NULL)
-			sprintf(screen, "screen %s", monitor_to_track);
-		sprintf(command, "Scroll %s %dp %dp", screen, psx, psy);
+			snprintf(screen, sizeof(screen), "screen %s", monitor_to_track);
+		snprintf(command, sizeof(command), "Scroll %s %dp %dp", screen, psx, psy);
 		SendText(fd, command, 0);
 		messages_sent++;
 		SendText(fd, "Send_Reply ScrollDone", 0);
@@ -441,31 +440,6 @@ void initialize_balloon_window(void)
 	return;
 }
 
-/* XXX: Here be dragons!  Ideally, this function should be parameterised,
- * however due to all the global state in FvwmPager, there's no point.  This
- * should get added to a clean up TODO at some point.
- */
-static void
-adjust_for_sizehints(int VxPages, int VyPages)
-{
-	int w_mult;
-	int h_mult;
-
-	w_mult = Columns * VxPages;
-	h_mult = Rows * VyPages;
-
-	/* Adjust window size to be even multiples of increment size. */
-	if (pwindow.width > 0) {
-		pwindow.width = (pwindow.width / w_mult + 1) * w_mult;
-	}
-	if (pwindow.height > 0) {
-		pwindow.height = (pwindow.height / h_mult + 1) * h_mult;
-	}
-
-	desk_w = (pwindow.width - Columns + 1) / Columns;
-	desk_h = (pwindow.height - Rows * label_h - Rows + 1) / Rows;
-}
-
 /* Computes pager size rectangle from fvwm size or visa versa */
 static void
 fvwmrec_to_pager(rectangle *rec, bool is_icon)
@@ -474,14 +448,15 @@ fvwmrec_to_pager(rectangle *rec, bool is_icon)
 
 	int m_width = monitor_get_all_widths();
 	int m_height = monitor_get_all_heights();
-	int offset_x = 0, offset_y = 0;
-
 	if (monitor_to_track != NULL) {
-		offset_x = (m_width - mon->w) * (rec->x / m_width) + mon->x;
-		offset_y = (m_height - mon->h) * (rec->y / m_height) + mon->y;
+		/* Offset window location based on monitor location. */
+		rec->x -= (m_width - mon->w) * (rec->x / m_width) + mon->x;
+		rec->y -= (m_height - mon->h) * (rec->y / m_height) + mon->y;
 		m_width = mon->w;
 		m_height = mon->h;
 	}
+	m_width *= mon->virtual_scr.VxPages;
+	m_height *= mon->virtual_scr.VyPages;
 
 	int scale_w = desk_w, scale_h = desk_h;
 	if ( is_icon ) {
@@ -489,16 +464,16 @@ fvwmrec_to_pager(rectangle *rec, bool is_icon)
 		scale_h = icon.height;
 	}
 
-	/* Due to rounding some windows may appear slightly off the page
-	 * edges when they are not. Should add some cleanup/snapping
-	 * code to help improve the visual effect.
+	/* To deal with rounding issues, first compute the right/bottom
+	 * location of the window so the rounding is consistent for windows
+	 * of different sizes at the same position.
 	 */
-	m_width = m_width * mon->virtual_scr.VxPages;
-	m_height = m_height * mon->virtual_scr.VyPages;
-	rec->width = (rec->width * scale_w) / m_width + 1;
-	rec->height = (rec->height * scale_h) / m_height + 1;
-	rec->x = ((rec->x - offset_x) * scale_w) / m_width;
-	rec->y = ((rec->y - offset_y) * scale_h) / m_height;
+	rec->width = ((rec->x + rec->width) * scale_w) / m_width;
+	rec->height = ((rec->y + rec->height) * scale_h) / m_height;
+	rec->x = (rec->x * scale_w) / m_width;
+	rec->y = (rec->y * scale_h) / m_height;
+	rec->width -= rec->x;
+	rec->height -= rec->y;
 }
 static void
 pagerrec_to_fvwm(rectangle *rec, bool is_icon)
@@ -538,12 +513,16 @@ set_vp_size_and_loc(void)
 	rectangle vp;
 	struct fpmonitor *mon = fpmonitor_this();
 
-	vp.width = desk_w / mon->virtual_scr.VxPages;
-	vp.height = desk_h / mon->virtual_scr.VyPages;
-	vp.x = (mon->virtual_scr.Vx * vp.width) /
-		mon->virtual_scr.MyDisplayWidth;
-	vp.y = (mon->virtual_scr.Vy * vp.height) /
-		mon->virtual_scr.MyDisplayHeight;
+	vp.x = (mon->virtual_scr.Vx * desk_w) /
+		mon->virtual_scr.VWidth;
+	vp.y = (mon->virtual_scr.Vy * desk_h) /
+		mon->virtual_scr.VHeight;
+	vp.width = ((mon->virtual_scr.Vx + mon->virtual_scr.VWidth /
+		     mon->virtual_scr.VxPages) * desk_w) /
+		     mon->virtual_scr.VWidth - vp.x;
+	vp.height = ((mon->virtual_scr.Vy + mon->virtual_scr.VHeight /
+		      mon->virtual_scr.VyPages) * desk_h) /
+		      mon->virtual_scr.VHeight - vp.y;
 	return vp;
 }
 
@@ -702,10 +681,8 @@ void initialize_pager(void)
 			  label_h * Rows + Rows;
 	  }
   }
-  /* Adjust the window to handle these new sizehints.  This is also called
-   * from ReConfigure().
-   */
-  adjust_for_sizehints(VxPages, VyPages);
+  desk_w = (pwindow.width - Columns + 1) / Columns;
+  desk_h = (pwindow.height - Rows * label_h - Rows + 1) / Rows;
 
   if (is_transient)
   {
@@ -1047,10 +1024,7 @@ void UpdateWindowShape(void)
     shape_count =
       ndesks + ((m->virtual_scr.CurrentDesk < desk1 || m->virtual_scr.CurrentDesk >desk2) ? 0 : 1);
 
-    shape = (XRectangle *)alloca (shape_count * sizeof (XRectangle));
-
-    if (shape == NULL)
-      return;
+    shape = fxmalloc(shape_count * sizeof (XRectangle));
 
     cnt = 0;
     y_pos = (LabelsBelow ? 0 : label_h);
@@ -1084,6 +1058,7 @@ void UpdateWindowShape(void)
 
     FShapeCombineRectangles(
       dpy, Scr.Pager_w, FShapeBounding, 0, 0, shape, shape_count, FShapeSet, 0);
+    free(shape);
   }
 }
 
@@ -1162,7 +1137,7 @@ void DispatchEvent(XEvent *Event)
       if (do_move_page)
       {
 	char command[64];
-	sprintf(command,"Scroll %d %d", dx, dy);
+	snprintf(command, sizeof(command),"Scroll %d %d", dx, dy);
 	SendText(fd, command, 0);
       }
     }
@@ -1429,25 +1404,15 @@ void ReConfigure(void)
   unsigned border_width, depth;
   rectangle vp = {0, 0, 0, 0};
   int i = 0, j = 0, k = 0;
-  int old_ww;
-  int old_wh;
-  int is_size_changed;
   struct fpmonitor *mon = fpmonitor_this();
-  int VxPages = mon->virtual_scr.VxPages, VyPages = mon->virtual_scr.VyPages;
 
-  old_ww = pwindow.width;
-  old_wh = pwindow.height;
   if (!XGetGeometry(dpy, Scr.Pager_w, &root, &vp.x, &vp.y, (unsigned *)&pwindow.width,
 		    (unsigned *)&pwindow.height, &border_width,&depth))
   {
     return;
   }
-  is_size_changed = (old_ww != pwindow.width || old_wh != pwindow.height);
-
-  adjust_for_sizehints(VxPages, VyPages);
-
-  XSetWMNormalHints(dpy,Scr.Pager_w,&sizehints);
-
+  desk_w = (pwindow.width - Columns + 1) / Columns;
+  desk_h = (pwindow.height - Rows * label_h - Rows + 1) / Rows;
   vp = set_vp_size_and_loc();
 
   for(k=0;k<Rows;k++)
@@ -1462,13 +1427,6 @@ void ReConfigure(void)
 	  desk_w,desk_h+label_h);
 	XMoveResizeWindow(
 	  dpy,Desks[i].w, -1, (LabelsBelow) ? -1 : label_h - 1, desk_w,desk_h);
-	if (!is_size_changed)
-	{
-		if (CSET_IS_TRANSPARENT(Desks[i].colorset))
-		{
-			draw_desk_background(i, vp.width, vp.height);
-		}
-	}
 	if (HilightDesks)
 	{
 	  if(i == mon->virtual_scr.CurrentDesk - desk1)
@@ -1633,7 +1591,8 @@ void MovePage(Bool is_new_desk)
     {
       if(i == mon->virtual_scr.CurrentDesk - desk1)
       {
-	XMoveWindow(dpy, Desks[i].CPagerWin, vp.x, vp.y);
+	XMoveResizeWindow(
+		dpy, Desks[i].CPagerWin, vp.x, vp.y, vp.width, vp.height);
 	XLowerWindow(dpy,Desks[i].CPagerWin);
 	if (CSET_IS_TRANSPARENT(Desks[i].highcolorset))
 	{
@@ -1661,7 +1620,7 @@ void MovePage(Bool is_new_desk)
       sptr = Desks[mon->virtual_scr.CurrentDesk -desk1].label;
     else
     {
-      sprintf(str, "GotoDesk %s %d", mon->name, mon->virtual_scr.CurrentDesk);
+      snprintf(str, sizeof(str), "GotoDesk %s %d", mon->name, mon->virtual_scr.CurrentDesk);
       sptr = &str[0];
     }
 
@@ -1816,7 +1775,7 @@ void DrawGrid(int desk, int erase, Window ew, XRectangle *r)
 	w = FlocaleTextWidth(Ffont,ptr,strlen(ptr));
 	if( w > desk_w)
 	{
-		sprintf(str,"%d",d);
+		snprintf(str,sizeof(str),"%d",d);
 		ptr = str;
 		w = FlocaleTextWidth(Ffont,ptr,strlen(ptr));
 	}
@@ -1932,8 +1891,9 @@ void SwitchToDesk(int Desk)
 	char command[256];
 	struct fpmonitor *m = fpmonitor_this();
 
-	sprintf(command, "GotoDesk %s 0 %d", monitor_to_track ? m->name : "",
-			Desk + desk1);
+	snprintf(command, sizeof(command),
+		"GotoDesk %s 0 %d", monitor_to_track ? m->name : "",
+		Desk + desk1);
 	SendText(fd,command,0);
 }
 
@@ -1957,7 +1917,7 @@ void SwitchToDeskAndPage(int Desk, XEvent *Event)
       vy = Event->xbutton.y * mon->virtual_scr.VHeight / (desk_h * mon->virtual_scr.MyDisplayHeight);
     mon->virtual_scr.Vx = vx * mon->virtual_scr.MyDisplayWidth;
     mon->virtual_scr.Vy = vy * mon->virtual_scr.MyDisplayHeight;
-    sprintf(command, "GotoDeskAndPage %s %d %d %d",
+    snprintf(command, sizeof(command), "GotoDeskAndPage %s %d %d %d",
 		monitor_to_track ? mon->name : "", Desk + desk1, vx, vy);
     SendText(fd, command, 0);
 
@@ -1985,7 +1945,7 @@ void SwitchToDeskAndPage(int Desk, XEvent *Event)
       x = mon->virtual_scr.VxMax / mon->virtual_scr.MyDisplayWidth;
     if (y * mon->virtual_scr.MyDisplayHeight > mon->virtual_scr.VyMax)
       y = mon->virtual_scr.VyMax / mon->virtual_scr.MyDisplayHeight;
-    sprintf(command, "GotoPage %s %d %d", monitor_to_track ? mon->name : "", x, y);
+    snprintf(command, sizeof(command), "GotoPage %s %d %d", monitor_to_track ? mon->name : "", x, y);
     SendText(fd, command, 0);
   }
   Wait = 1;
@@ -1996,7 +1956,7 @@ void IconSwitchPage(XEvent *Event)
   char command[34];
   struct fpmonitor *mon = fpmonitor_this();
 
-  sprintf(command,"GotoPage %s %d %d",
+  snprintf(command,sizeof(command),"GotoPage %s %d %d",
 	  monitor_to_track ? mon->name : "",
 	  Event->xbutton.x * mon->virtual_scr.VWidth /
 		  (icon.width * mon->virtual_scr.MyDisplayWidth),
@@ -2639,7 +2599,7 @@ void MoveWindow(XEvent *Event)
 					ChangeDeskForWindow(t,mon->virtual_scr.CurrentDesk);
 			}
 			else if (NewDesk + desk1 != mon->virtual_scr.CurrentDesk) {
-				sprintf(command, "Silent MoveToDesk 0 %d",
+				snprintf(command, sizeof(command), "Silent MoveToDesk 0 %d",
 					NewDesk + desk1);
 				SendText(fd, command, t->w);
 				t->desk = NewDesk + desk1;
@@ -2659,7 +2619,7 @@ void MoveWindow(XEvent *Event)
 				/* XXX: Note the use of ewmhiwa to disable
 				 * clipping the coordinates to the wrong area!
 				 */
-				sprintf(buf, "Silent Move +%dp +%dp ewmhiwa",
+				snprintf(buf, sizeof(buf), "Silent Move +%dp +%dp ewmhiwa",
 					rec.x, rec.y);
 				SendText(fd, buf, t->w);
 				XSync(dpy,0);
@@ -2670,7 +2630,7 @@ void MoveWindow(XEvent *Event)
 		}
 
 		if (do_switch_desk_later) {
-			sprintf(command, "Silent MoveToDesk 0 %d", NewDesk +
+			snprintf(command, sizeof(command), "Silent MoveToDesk 0 %d", NewDesk +
 				desk1);
 			SendText(fd, command, t->w);
 			t->desk = NewDesk + desk1;
@@ -3034,7 +2994,7 @@ void IconMoveWindow(XEvent *Event, PagerWindow *t)
 
 		if (moved) {
 			char buf[64];
-			sprintf(buf, "Silent Move +%dp +%dp ewmhiwa",
+			snprintf(buf, sizeof(buf), "Silent Move +%dp +%dp ewmhiwa",
 				rec.x, rec.y);
 			SendText(fd, buf, t->w);
 			XSync(dpy, 0);
